@@ -46,6 +46,13 @@
 #define ENCODE_MIM_SEGID_BLOCK_SIZE 32
 #define ENCODE_AV1_MIN_ICQ_QUALITYFACTOR      0
 #define ENCODE_AV1_MAX_ICQ_QUALITYFACTOR      255
+#define ENCODE_AV1_ORDER_HINT_SIZE            256
+// for VAConfigAttribValEncAV1Ext2.tx_mode_support
+#define AV1_TX_MODE_ONLY_4X4_SUPPORTED 0x01
+#define AV1_TX_MODE_LARGEST_SUPPORTED 0x02
+#define AV1_TX_MODE_SELECT_SUPPORTED 0x04
+#define AV1_MAX_NUM_OF_BATCH_BUFFER 5
+#define AV1_MAX_NUM_OF_SEGMENTS 8
 constexpr uint32_t TILE_SIZE_BYTES = 4;
 const uint8_t OBU_LEB128_SIZE  = 4;
 const uint8_t LEB128_BYTE_MASK = 0x7f;
