@@ -248,6 +248,29 @@ public:
     {
         return nullptr;
     }
+
+    //!
+    //! \brief  Get OCA status.
+    //! \return MOS_STATUS
+    //!         Return oca status
+    //!
+    virtual MOS_STATUS GetOCAStatus() = 0;
+
+    //!
+    //! \brief  Set OCA status
+    //! \param  [in] status
+    //!         oca status.
+    //! \return void
+    //!
+    virtual void SetOCAStatus(MOS_STATUS status) = 0;
+
+    //!
+    //! \brief  Set OCA error line number
+    //! \param  [in] num
+    //!         line number
+    //! \return void
+    //!
+    virtual void SetOCAErrorLineNumber(uint32_t num) = 0;
 };
 
 #endif // #ifndef __MOS_OCA_INTERFACE_H__
