@@ -254,6 +254,12 @@ bool VPHAL_VEBOX_STATE_XE_XPM::IsNeeded(
     VPHAL_RENDER_CHK_NULL_NO_STATUS(pcRenderParams);
     VPHAL_RENDER_CHK_NULL_NO_STATUS(pcRenderParams->pTarget[0]);
 
+    if (pcRenderParams->bForceToRender)
+    {
+        pRenderPassData->bCompNeeded = true;
+        goto finish;
+    }
+
     pVeboxInterface         = pVeboxState->m_pVeboxInterface;
     pVeboxInterfaceXe_Xpm = (MhwVeboxInterfaceXe_Xpm *)pVeboxInterface;
     pOsInterface            = pVeboxState->m_pOsInterface;
@@ -824,12 +830,12 @@ MOS_STATUS VPHAL_VEBOX_STATE_XE_XPM::VeboxRenderVeboxCmd(
 {
     MOS_STATUS                        eStatus     = MOS_STATUS_SUCCESS;
     PVPHAL_VEBOX_RENDER_DATA          pRenderData = GetLastExecRenderData();
-    MhwVeboxInterfaceXe_Xpm *       pVeboxInterfaceXe_Xpm;
+    MhwVeboxInterfaceXe_Xpm *         pVeboxInterfaceXe_Xpm;
     PMHW_VEBOX_INTERFACE              pVeboxInterface;
     MHW_MI_ATOMIC_PARAMS              AtomicParams;
     MHW_MI_SEMAPHORE_WAIT_PARAMS      MiSemaphoreWaitParams;
-    PVPHAL_VEBOX_STATE_XE_XPM        pVeboxState = this;
-    PRENDERHAL_INTERFACE              pRenderHal;
+    PVPHAL_VEBOX_STATE_XE_XPM         pVeboxState = this;
+    PRENDERHAL_INTERFACE_LEGACY       pRenderHal;
     bool                              bDiVarianceEnable;
     PMOS_INTERFACE                    pOsInterface;
     uint32_t                          IdxofVebox;
@@ -902,7 +908,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_XE_XPM::VeboxRenderVeboxCmd(
             if (pOsInterface->apoMosEnabled)
             {
                 VPHAL_RENDER_CHK_NULL(pOsInterface->osStreamState);
-                VPHAL_RENDER_CHK_STATUS(MosInterface::SetupAttributeVeBuffer(pOsInterface->osStreamState, &CmdBuffer));
+                VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnSetupAttributeVeBuffer(pOsInterface->osStreamState, &CmdBuffer));
             }
             CmdBuffer.Attributes.pAttriVe = &pOsInterface->bufAttriVe[pOsInterface->CurrentGpuContextOrdinal];
         }
@@ -1026,7 +1032,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_XE_XPM::VeboxRenderVeboxCmd(
                 *pRenderHal->pMhwMiInterface, *pMmioRegisters);
 
             // Add vphal param to log.
-            HalOcaInterface::DumpVphalParam(*pCmdBufferInUse, *pOsContext, pRenderHal->pVphalOcaDumper);
+            HalOcaInterface::DumpVphalParam(*pCmdBufferInUse, (MOS_CONTEXT_HANDLE)pOsContext, pRenderHal->pVphalOcaDumper);
 
             // Profiler start cmd
             if (pRenderHal->pPerfProfiler)
@@ -1034,7 +1040,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_XE_XPM::VeboxRenderVeboxCmd(
                 VPHAL_RENDER_CHK_STATUS(pRenderHal->pPerfProfiler->AddPerfCollectStartCmd((void*)pRenderHal, pOsInterface, pRenderHal->pMhwMiInterface, pCmdBufferInUse));
             }
 
-            VPHAL_RENDER_CHK_STATUS(NullHW::StartPredicate(pRenderHal->pMhwMiInterface, pCmdBufferInUse));
+            VPHAL_RENDER_CHK_STATUS(NullHW::StartPredicate(pOsInterface, pRenderHal->pMhwMiInterface, pCmdBufferInUse));
 
             // Insert prolog with VE params
             VPHAL_RENDER_CHK_STATUS(pVeboxInterfaceXe_Xpm->setVeboxPrologCmd(m_pRenderHal->pMhwMiInterface, pCmdBufferInUse));
@@ -1129,7 +1135,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_XE_XPM::VeboxRenderVeboxCmd(
                     pCmdBufferInUse));
             }
 
-            HalOcaInterface::OnDispatch(*pCmdBufferInUse, *pOsContext, *pRenderHal->pMhwMiInterface, *pMmioRegisters);
+            HalOcaInterface::OnDispatch(*pCmdBufferInUse, *pOsInterface, *pRenderHal->pMhwMiInterface, *pMmioRegisters);
 
             //---------------------------------
             // Send CMD: Vebox_DI_IECP
@@ -1211,7 +1217,7 @@ MOS_STATUS VPHAL_VEBOX_STATE_XE_XPM::VeboxRenderVeboxCmd(
             VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMiStoreDataImmCmd(
                 pCmdBufferInUse, &dataParams));
 
-            VPHAL_RENDER_CHK_STATUS(NullHW::StopPredicate(pRenderHal->pMhwMiInterface, &CmdBuffer));
+            VPHAL_RENDER_CHK_STATUS(NullHW::StopPredicate(pOsInterface, pRenderHal->pMhwMiInterface, &CmdBuffer));
 
             // Profiler end cmd
             if (pRenderHal->pPerfProfiler)
@@ -1287,11 +1293,13 @@ MOS_STATUS VPHAL_VEBOX_STATE_XE_XPM::VeboxRenderVeboxCmd(
 
         VPHAL_RENDER_CHK_STATUS(UnLockVESecondaryCmdBuffers());
 
+#if (_DEBUG || _RELEASE_INTERNAL)
         ReportUserSetting(
             m_userSettingPtr,
             __MEDIA_USER_FEATURE_VALUE_ENABLE_VEBOX_SCALABILITY_MODE,
             veboxEnableScalability,
-            MediaUserSetting::Group::Sequence);
+            MediaUserSetting::Group::Device);
+#endif
     }
     else
     {
@@ -1320,11 +1328,13 @@ MOS_STATUS VPHAL_VEBOX_STATE_XE_XPM::VeboxRenderVeboxCmd(
             pGenericPrologParams));
 
         veboxEnableScalability = false;
+#if (_DEBUG || _RELEASE_INTERNAL)
         ReportUserSetting(
             m_userSettingPtr,
             __MEDIA_USER_FEATURE_VALUE_ENABLE_VEBOX_SCALABILITY_MODE,
             veboxEnableScalability,
-            MediaUserSetting::Group::Sequence);
+            MediaUserSetting::Group::Device);
+#endif
     }
 
 finish:
