@@ -36,7 +36,6 @@
 #include "codec_def_decode_av1.h"
 #include "codec_def_common_av1.h"
 
-
 /**
  * @brief Perse tile parameter
  *
@@ -49,7 +48,7 @@
 VAStatus DdiDecodeAV1::ParseTileParams(
     DDI_MEDIA_CONTEXT         *mediaCtx,
     VASliceParameterBufferAV1 *slcParam,
-    uint32_t                       numTiles)
+    uint32_t                   numTiles)
 {
     CodecAv1TileParams     *tileParams;
     VASliceParameterBufferAV1 *pTileCtrl = nullptr;
@@ -215,11 +214,16 @@ VAStatus DdiDecodeAV1::ParsePicParams(
         if (picParam->ref_frame_map[i] < mediaCtx->uiNumSurfaces)
         {
             frameIdx = GetRenderTargetID(&m_ddiDecodeCtx->RTtbl, refSurface);
-            if (frameIdx == DDI_CODEC_INVALID_FRAME_INDEX) {
-                return VA_STATUS_ERROR_INVALID_PARAMETER;
+       
+            if ((frameIdx == DDI_CODEC_INVALID_FRAME_INDEX) && 
+                (picParam->pic_info_fields.bits.frame_type != keyFrame) && 
+                (picParam->pic_info_fields.bits.frame_type != intraOnlyFrame))
+            {
+                 return VA_STATUS_ERROR_INVALID_PARAMETER;
             }
-            picAV1Params->m_refFrameMap[i].FrameIdx = ((uint32_t)frameIdx >= CODECHAL_NUM_UNCOMPRESSED_SURFACE_VP9) ?
-                                                      (CODECHAL_NUM_UNCOMPRESSED_SURFACE_VP9 - 1) : frameIdx;
+
+            picAV1Params->m_refFrameMap[i].FrameIdx = ((uint32_t)frameIdx >= CODECHAL_NUM_UNCOMPRESSED_SURFACE_AV1) ?
+                                                      (CODECHAL_NUM_UNCOMPRESSED_SURFACE_AV1 - 1) : frameIdx;
         }
         else
         {
@@ -228,17 +232,17 @@ VAStatus DdiDecodeAV1::ParsePicParams(
                 frameIdx = GetRenderTargetID(&m_ddiDecodeCtx->RTtbl, refSurface);
                 if (frameIdx != DDI_CODEC_INVALID_FRAME_INDEX)
                 {
-                    picAV1Params->m_refFrameMap[i].FrameIdx = ((uint32_t)frameIdx >= CODECHAL_NUM_UNCOMPRESSED_SURFACE_VP9) ?
-                                                              (CODECHAL_NUM_UNCOMPRESSED_SURFACE_VP9 - 1) : frameIdx;
+                    picAV1Params->m_refFrameMap[i].FrameIdx = ((uint32_t)frameIdx >= CODECHAL_NUM_UNCOMPRESSED_SURFACE_AV1) ?
+                                                              (CODECHAL_NUM_UNCOMPRESSED_SURFACE_AV1 - 1) : frameIdx;
                 }
                 else
                 {
-                    picAV1Params->m_refFrameMap[i].FrameIdx = CODECHAL_NUM_UNCOMPRESSED_SURFACE_VP9 - 1;
+                    picAV1Params->m_refFrameMap[i].FrameIdx = CODECHAL_NUM_UNCOMPRESSED_SURFACE_AV1 - 1;
                 }
             }
             else
             {
-                picAV1Params->m_refFrameMap[i].FrameIdx = CODECHAL_NUM_UNCOMPRESSED_SURFACE_VP9 - 1;
+                picAV1Params->m_refFrameMap[i].FrameIdx = CODECHAL_NUM_UNCOMPRESSED_SURFACE_AV1 - 1;
             }
         }
     }
@@ -457,6 +461,23 @@ VAStatus DdiDecodeAV1::ParsePicParams(
     MOS_SecureMemcpy(picAV1Params->m_heightInSbsMinus1, 63 * sizeof(uint16_t),
                      picParam->height_in_sbs_minus_1,   63 * sizeof(uint16_t));
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    // Picture Info
+    uint32_t subSamplingSum = picAV1Params->m_seqInfoFlags.m_fields.m_subsamplingX + picAV1Params->m_seqInfoFlags.m_fields.m_subsamplingY;
+    DECODE_EVENTDATA_INFO_PICTUREVA eventData = {0};
+    eventData.CodecFormat                   = m_ddiDecodeCtx->wMode;
+    eventData.FrameType                     = picAV1Params->m_picInfoFlags.m_fields.m_frameType == 0 ? I_TYPE : MIXED_TYPE;
+    eventData.PicStruct                     = FRAME_PICTURE;
+    eventData.Width                         = picAV1Params->m_frameWidthMinus1 + 1;
+    eventData.Height                        = picAV1Params->m_frameHeightMinus1 + 1;
+    eventData.Bitdepth                      = picAV1Params->m_bitDepthIdx;
+    eventData.ChromaFormat                  = (subSamplingSum == 2) ? 1 : (subSamplingSum == 1 ? 2 : 3);  // 1-4:2:0; 2-4:2:2; 3-4:4:4
+    eventData.EnabledSCC                    = picAV1Params->m_picInfoFlags.m_fields.m_allowScreenContentTools;
+    eventData.EnabledSegment                = picAV1Params->m_av1SegData.m_enabled;
+    eventData.EnabledFilmGrain              = picAV1Params->m_seqInfoFlags.m_fields.m_filmGrainParamsPresent;
+    MOS_TraceEvent(EVENT_DECODE_INFO_PICTUREVA, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -475,6 +496,14 @@ VAStatus DdiDecodeAV1::SetDecodeParams()
         procParams->m_inputSurface->dwHeight = procParams->m_inputSurface->OsResource.iHeight;
         procParams->m_inputSurface->dwPitch  = procParams->m_inputSurface->OsResource.iPitch;
         procParams->m_inputSurface->Format   = procParams->m_inputSurface->OsResource.Format;
+
+        if(m_requireInputRegion)
+        {
+            procParams->m_inputSurfaceRegion.m_x = 0;
+            procParams->m_inputSurfaceRegion.m_y = 0;
+            procParams->m_inputSurfaceRegion.m_width = procParams->m_inputSurface->dwWidth;
+            procParams->m_inputSurfaceRegion.m_height = procParams->m_inputSurface->dwHeight;
+        }
     }
 #endif
     CodecAv1PicParams *Av1PicParams = static_cast<CodecAv1PicParams *>(m_ddiDecodeCtx->DecodeParams.m_picParams);
@@ -575,6 +604,7 @@ VAStatus DdiDecodeAV1::RenderPicture(
             DdiMedia_MediaBufferToMosResource(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index],
                                               &m_ddiDecodeCtx->BufMgr.resBitstreamBuffer);
             m_ddiDecodeCtx->DecodeParams.m_dataSize += dataSize;
+
             break;
         }
         case VASliceParameterBufferType:
