@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2022, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -25,7 +25,6 @@
 //!
 #include "encode_av1_vdenc_packet_xe_m_base.h"
 #include "mos_solo_generic.h"
-#include "media_user_settings_mgr_g12_plus.h"
 #include "mhw_mi_itf.h"
 #include "mhw_vdbox_g12_X.h"
 
@@ -68,7 +67,7 @@ namespace encode
         m_resCumulativeCuCountStreamoutBuffer = m_allocator->AllocateResource(allocParams, false);
         if (m_resCumulativeCuCountStreamoutBuffer == nullptr)
         {
-            CODECHAL_ENCODE_ASSERTMESSAGE("Failed to allocate VDEnc Cumulative CU Count Streamout Surface.");
+            ENCODE_ASSERTMESSAGE("Failed to allocate VDEnc Cumulative CU Count Streamout Surface.");
             return MOS_STATUS_UNKNOWN;
         }
 
@@ -83,7 +82,7 @@ namespace encode
 
         if (m_basicFeature->m_resMfdIntraRowStoreScratchBuffer == nullptr)
         {
-            CODECHAL_ENCODE_ASSERTMESSAGE("Failed to allocate VDEnc Tile Row Store Buffer.");
+            ENCODE_ASSERTMESSAGE("Failed to allocate VDEnc Tile Row Store Buffer.");
             return MOS_STATUS_UNKNOWN;
         }
 
@@ -94,7 +93,7 @@ namespace encode
 
         if (m_vdencTileRowStoreBuffer == nullptr)
         {
-            CODECHAL_ENCODE_ASSERTMESSAGE("Failed to allocate VDEnc Tile Row Store Buffer.");
+            ENCODE_ASSERTMESSAGE("Failed to allocate VDEnc Tile Row Store Buffer.");
             return MOS_STATUS_UNKNOWN;
         }
 
@@ -255,43 +254,6 @@ namespace encode
         allocParams.pBufName = "Tile Statistics Streamout Buffer";
         m_basicFeature->m_tileStatisticsPakStreamoutBuffer = m_allocator->AllocateResource(allocParams, false);
 
-        if(m_osInterface->bInlineCodecStatusUpdate)
-        {
-            MOS_LOCK_PARAMS lockFlagsWriteOnly;
-            MOS_ZeroMemory(&lockFlagsWriteOnly, sizeof(MOS_LOCK_PARAMS));
-            lockFlagsWriteOnly.WriteOnly = 1;
-
-            m_atomicScratchBuf.size = MOS_ALIGN_CEIL(sizeof(AtomicScratchBuffer), sizeof(uint64_t));
-
-            uint32_t size  = MHW_CACHELINE_SIZE * 4 * 2; //  each set of scratch is 4 cacheline size, and allocate 2 set.
-            allocParams.dwBytes  = size;
-            allocParams.pBufName = "atomic sratch buffer";
-
-            m_atomicScratchBuf.resAtomicScratchBuffer = m_allocator->AllocateResource(allocParams, false);
-
-            ENCODE_CHK_NULL_RETURN(m_atomicScratchBuf.resAtomicScratchBuffer);
-
-            uint8_t* data = (uint8_t*)m_osInterface->pfnLockResource(
-                m_osInterface,
-                m_atomicScratchBuf.resAtomicScratchBuffer,
-                &lockFlagsWriteOnly);
-
-            ENCODE_CHK_NULL_RETURN(data);
-
-            MOS_ZeroMemory(data, size);
-            m_atomicScratchBuf.pData              = (uint32_t*)data;
-            m_atomicScratchBuf.size               = size;
-            m_atomicScratchBuf.zeroValueOffset    = 0;
-            m_atomicScratchBuf.operand1Offset     = MHW_CACHELINE_SIZE;
-            m_atomicScratchBuf.operand2Offset     = MHW_CACHELINE_SIZE * 2;
-            m_atomicScratchBuf.operand3Offset     = MHW_CACHELINE_SIZE * 3;
-            m_atomicScratchBuf.encodeUpdateIndex  = 0;
-            m_atomicScratchBuf.tearDownIndex      = 1;
-            m_atomicScratchBuf.operandSetSize     = MHW_CACHELINE_SIZE * 4;
-
-            ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnUnlockResource(m_osInterface, m_atomicScratchBuf.resAtomicScratchBuffer));
-        }
-
         return MOS_STATUS_SUCCESS;
 
     }
@@ -307,11 +269,14 @@ namespace encode
         allocParamsForBuffer2D.dwWidth            = MOS_ALIGN_CEIL(m_basicFeature->m_frameWidth, av1SuperBlockWidth);
         allocParamsForBuffer2D.dwHeight           = MOS_ALIGN_CEIL(m_basicFeature->m_frameHeight, av1SuperBlockHeight);
 
+#ifdef _MMC_SUPPORTED
+        ENCODE_CHK_NULL_RETURN(m_mmcState);
         if (m_mmcState->IsMmcEnabled() && m_basicFeature->m_reconSurface.bCompressible)
         {
             allocParamsForBuffer2D.CompressionMode = MOS_MMC_MC;
             allocParamsForBuffer2D.bIsCompressible = true;
         }
+#endif
         if (m_basicFeature->m_is10Bit)
         {
             // This is temporary fix for Sim specific ( Grits Utility) issue, HW has no restriction for current platform
@@ -352,7 +317,7 @@ namespace encode
         syncParams.GpuContext = m_osInterface->pfnGetGpuContext(m_osInterface);
         syncParams.presSyncResource = &m_basicFeature->m_rawSurface.OsResource;
         syncParams.bReadOnly = true;
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnResourceWait(m_osInterface, &syncParams));
+        ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnResourceWait(m_osInterface, &syncParams));
         m_osInterface->pfnSetResourceSyncTag(m_osInterface, &syncParams);
 
         // Set flag to boost GPU frequency for low latency in remote gaming scenario
@@ -384,9 +349,7 @@ namespace encode
 
         ENCODE_CHK_STATUS_RETURN(m_miItf->SetWatchdogTimerThreshold(m_basicFeature->m_frameWidth, m_basicFeature->m_frameHeight, true));
 
-        uint16_t perfTag = m_pipeline->IsFirstPass() ? CODECHAL_ENCODE_PERFTAG_CALL_PAK_ENGINE : CODECHAL_ENCODE_PERFTAG_CALL_PAK_ENGINE_SECOND_PASS;
-        uint16_t pictureType = (m_basicFeature->m_pictureCodingType == I_TYPE) ? 1 : (m_basicFeature->m_ref.IsLowDelay() ? (m_basicFeature->m_ref.IsPFrame() ? 2 : 0) : 3);
-        SetPerfTag(perfTag, (uint16_t)m_basicFeature->m_mode, pictureType);
+        SetPerfTag();
 
         bool firstTaskInPhase = packetPhase & firstPacket;
         if (!m_pipeline->IsSingleTaskPhaseSupported() || firstTaskInPhase)
@@ -397,6 +360,30 @@ namespace encode
             ENCODE_CHK_STATUS_RETURN(SendPrologCmds(cmdBuffer));
         }
 
+        if (m_pipeline->GetPipeNum() >= 2)
+        {
+            auto scalability = m_pipeline->GetMediaScalability();
+            if (m_pipeline->IsFirstPass())
+            {
+                ENCODE_CHK_STATUS_RETURN(scalability->ResetSemaphore(syncOnePipeWaitOthers, 0, &cmdBuffer));
+
+                if(m_pipeline->IsFirstPipe())
+                {
+                    PMOS_RESOURCE bsSizeBuf = m_basicFeature->m_recycleBuf->GetBuffer(PakInfo, 0);
+                    ENCODE_CHK_NULL_RETURN(bsSizeBuf);
+                    // clear bitstream size buffer at first tile
+                    auto &miStoreDataParams            = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
+                    miStoreDataParams                  = {};
+                    miStoreDataParams.pOsResource      = bsSizeBuf;
+                    miStoreDataParams.dwResourceOffset = 0;
+                    miStoreDataParams.dwValue          = 0;
+                    ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(&cmdBuffer));
+                }
+
+            }
+            ENCODE_CHK_STATUS_RETURN(scalability->SyncPipe(syncOtherPipesForOne, 0, &cmdBuffer));
+        }
+
         ENCODE_CHK_STATUS_RETURN(AddCondBBEndFor2ndPass(cmdBuffer));
 
         if (m_pipeline->IsFirstPipe())
@@ -540,7 +527,7 @@ namespace encode
             ENCODE_CHK_NULL_RETURN(tileLevelBatchBuffer);
             tileLevelBatchBuffer->iCurrent = constructTileBatchBuf.iOffset;
             tileLevelBatchBuffer->iRemaining = constructTileBatchBuf.iRemaining;
-            CODECHAL_ENCODE_CHK_STATUS_RETURN(m_miItf->AddMiBatchBufferEnd(nullptr, tileLevelBatchBuffer));
+            ENCODE_CHK_STATUS_RETURN(m_miItf->AddMiBatchBufferEnd(nullptr, tileLevelBatchBuffer));
         }
 
     #if MHW_HWCMDPARSER_ENABLED
@@ -552,19 +539,27 @@ namespace encode
     #endif
 
 #if USE_CODECHAL_DEBUG_TOOL
+        std::string             name           = std::to_string(tileRow) + std::to_string(tileCol) + std::to_string(tileRowPass) + "_TILE_CMD_BUFFER";
         CodechalDebugInterface* debugInterface = m_pipeline->GetDebugInterface();
         ENCODE_CHK_NULL_RETURN(debugInterface);
 
         ENCODE_CHK_STATUS_RETURN(debugInterface->DumpCmdBuffer(
             &constructTileBatchBuf,
             CODECHAL_NUM_MEDIA_STATES,
-            "_TILE_CMD_BUFFER"));
+            name.c_str()));
 #endif
 
         // End patching tile level batch cmds
         RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, EndPatchTileLevelBatch);
 
-        ENCODE_CHK_STATUS_RETURN(ReadPakMmioRegisters(&cmdBuffer, tileRow == 0 && tileCol == 0));
+        if (m_pipeline->GetPipeNum() > 1)
+        {
+            ENCODE_CHK_STATUS_RETURN(ReadPakMmioRegistersAtomic(&cmdBuffer));
+        }
+        else
+        {
+            ENCODE_CHK_STATUS_RETURN(ReadPakMmioRegisters(&cmdBuffer, tileRow == 0 && tileCol == 0));
+        }
 
         return MOS_STATUS_SUCCESS;
     }
@@ -626,24 +621,22 @@ namespace encode
 
         ENCODE_CHK_STATUS_RETURN(EnsureAllCommandsExecuted(cmdBuffer));
 
-#if USE_CODECHAL_DEBUG_TOOL
-        ENCODE_CHK_STATUS_RETURN(Av1VdencPkt::PopulateParFileParams());
-#endif  // USE_CODECHAL_DEBUG_TOOL
-
         // Wait all pipe cmds done for the packet
         auto scalability = m_pipeline->GetMediaScalability();
         ENCODE_CHK_STATUS_RETURN(scalability->SyncPipe(syncOnePipeWaitOthers, 0, &cmdBuffer));
 
-        ENCODE_CHK_STATUS_RETURN(EndStatusReport(statusReportMfx, &cmdBuffer));
+        if (m_pipeline->IsFirstPipe()) 
+        {
+            ENCODE_CHK_STATUS_RETURN(EndStatusReport(statusReportMfx, &cmdBuffer));
+        }
+        auto brcFeature = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
+        ENCODE_CHK_NULL_RETURN(brcFeature);
 
         if (Mos_Solo_Extension(m_osInterface->pOsContext))
         {
-            if (m_pipeline->IsLastPass() && m_pipeline->IsFirstPipe())
-            {
-                ENCODE_CHK_STATUS_RETURN(MediaPacket::UpdateStatusReportNext(statusReportGlobalCount, &cmdBuffer));
-            }
+            ENCODE_CHK_STATUS_RETURN(MediaPacket::UpdateStatusReportNext(statusReportGlobalCount, &cmdBuffer));
         }
-        else if (m_osInterface->bInlineCodecStatusUpdate)
+        else if (brcFeature->IsBRCEnabled() && m_osInterface->bInlineCodecStatusUpdate)
         {
             ENCODE_CHK_STATUS_RETURN(UpdateStatusReport(statusReportGlobalCount, &cmdBuffer));
         }
@@ -692,9 +685,6 @@ namespace encode
         ENCODE_CHK_NULL_RETURN(statusReport);
         ENCODE_CHK_NULL_RETURN(m_hwInterface);
 
-        auto hwInterfaceG12 = dynamic_cast<CodechalHwInterfaceG12 *>(m_hwInterface);
-        ENCODE_CHK_NULL_RETURN(hwInterfaceG12);
-
         MOS_RESOURCE *osResource    = nullptr;
         uint32_t     offset         = 0;
 
@@ -717,9 +707,51 @@ namespace encode
         params.resImageStatusCtrl    = osResource;
         params.imageStatusCtrlOffset = offset;
 
-        ENCODE_CHK_STATUS_RETURN(hwInterfaceG12->ReadAvpStatus(vdboxIndex, params, &cmdBuffer));
+        //hwInterfaceG12->ReadAvpStatus
+        //auto hwInterfaceG12 = dynamic_cast<CodechalHwInterfaceG12 *>(m_hwInterface);
+        //ENCODE_CHK_NULL_RETURN(hwInterfaceG12);
+        //ENCODE_CHK_STATUS_RETURN(hwInterfaceG12->ReadAvpStatus(vdboxIndex, params, &cmdBuffer));
+        CODECHAL_HW_CHK_COND_RETURN((vdboxIndex > m_hwInterface->GetMaxVdboxIndex()), "ERROR - vdbox index exceed the maximum");
 
-        ENCODE_CHK_STATUS_RETURN(hwInterfaceG12->ReadImageStatusForAvp(vdboxIndex, params, &cmdBuffer));
+        auto &flushDwParams = m_miItf->MHW_GETPAR_F(MI_FLUSH_DW)();
+        flushDwParams       = {};
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(&cmdBuffer));
+
+        CODECHAL_HW_CHK_NULL_RETURN(m_avpItf);
+        auto mmioRegisters = m_avpItf->GetMmioRegisters(vdboxIndex);
+
+        auto &miStoreRegMemParams           = m_miItf->MHW_GETPAR_F(MI_STORE_REGISTER_MEM)();
+        miStoreRegMemParams                 = {};
+        miStoreRegMemParams.presStoreBuffer = params.resBitstreamByteCountPerFrame;
+        miStoreRegMemParams.dwOffset        = params.bitstreamByteCountPerFrameOffset;
+        miStoreRegMemParams.dwRegister      = mmioRegisters->avpAv1BitstreamByteCountTileRegOffset;
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
+
+        miStoreRegMemParams                 = {};
+        miStoreRegMemParams.presStoreBuffer = params.resQpStatusCount;
+        miStoreRegMemParams.dwOffset        = params.qpStatusCountOffset;
+        miStoreRegMemParams.dwRegister      = mmioRegisters->avpAv1QpStatusCountRegOffset;
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
+
+        //ENCODE_CHK_STATUS_RETURN(hwInterfaceG12->ReadImageStatusForAvp(vdboxIndex, params, &cmdBuffer));
+        //std::shared_ptr<mhw::vdbox::avp::Itf> m_avpItf = GetAvpInterfaceNext();
+        //CODECHAL_HW_CHK_NULL_RETURN(m_avpItf);
+        //auto mmioRegisters = m_avpItf->GetMmioRegisters(vdboxIndex);
+
+        miStoreRegMemParams                 = {};
+        miStoreRegMemParams.presStoreBuffer = params.resImageStatusMask;
+        miStoreRegMemParams.dwOffset        = params.imageStatusMaskOffset;
+        miStoreRegMemParams.dwRegister      = mmioRegisters->avpAv1ImageStatusMaskRegOffset;
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
+
+        miStoreRegMemParams                 = {};
+        miStoreRegMemParams.presStoreBuffer = params.resImageStatusCtrl;
+        miStoreRegMemParams.dwOffset        = params.imageStatusCtrlOffset;
+        miStoreRegMemParams.dwRegister      = mmioRegisters->avpAv1ImageStatusControlRegOffset;
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
+
+        flushDwParams       = {};
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(&cmdBuffer));
 
         return eStatus;
     }
@@ -819,6 +851,7 @@ namespace encode
     {
         ENCODE_FUNC_CALL();
 
+        ENCODE_CHK_NULL_RETURN(m_osInterface);
         auto& params = m_avpItf->MHW_GETPAR_F(AVP_PAK_INSERT_OBJECT)();
         params      = {};
 
@@ -850,7 +883,7 @@ namespace encode
                 uint32_t nalUnitSize   = m_nalUnitParams[i]->uiSize;
                 uint32_t nalUnitOffset = m_nalUnitParams[i]->uiOffset;
 
-                CODECHAL_ENCODE_ASSERT(nalUnitSize < CODECHAL_ENCODE_AV1_PAK_INSERT_UNCOMPRESSED_HEADER);
+                ENCODE_ASSERT(nalUnitSize < CODECHAL_ENCODE_AV1_PAK_INSERT_UNCOMPRESSED_HEADER);
 
                 params.bitSize    = nalUnitSize * 8;
                 params.offset     = nalUnitOffset;
@@ -868,13 +901,13 @@ namespace encode
                     else
                     {
                         m_avpItf->MHW_ADDCMD_F(AVP_PAK_INSERT_OBJECT)(cmdBuffer);
-                        Mos_AddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
+                        m_osInterface->pfnAddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
                     }
                 }
                 else
                 {
                     m_avpItf->MHW_ADDCMD_F(AVP_PAK_INSERT_OBJECT)(cmdBuffer);
-                    Mos_AddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
+                    m_osInterface->pfnAddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
                 }
             }
         }
@@ -891,262 +924,20 @@ namespace encode
             if (params.bitSize)
             {
                 m_avpItf->MHW_ADDCMD_F(AVP_PAK_INSERT_OBJECT)(cmdBuffer);
-                Mos_AddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
+                m_osInterface->pfnAddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
             }
         }
 
         return MOS_STATUS_SUCCESS;
     }
 
-    MOS_STATUS Av1VdencPktXe_M_Base::UpdateStatusReport(uint32_t srType, MOS_COMMAND_BUFFER *cmdBuffer)
-    {
-        ENCODE_FUNC_CALL();
-        ENCODE_CHK_NULL_RETURN(cmdBuffer);
-
-        //initialize following
-        MOS_RESOURCE *osResourceInline = nullptr;
-        uint32_t      offsetInline     = 0;
-        m_statusReport->GetAddress(statusReportGlobalCount, osResourceInline, offsetInline);
-        offsetInline             = m_atomicScratchBuf.operandSetSize * m_atomicScratchBuf.encodeUpdateIndex;
-        uint32_t zeroValueOffset = offsetInline;
-        uint32_t operand1Offset  = offsetInline + m_atomicScratchBuf.operand1Offset;
-        uint32_t operand2Offset  = offsetInline + m_atomicScratchBuf.operand2Offset;
-        uint32_t operand3Offset  = offsetInline + m_atomicScratchBuf.operand3Offset;
-        auto     mmioRegisters   = m_hwInterface->SelectVdboxAndGetMmioRegister(m_vdboxIndex, cmdBuffer);
-
-        // Make Flush DW call to make sure all previous work is done
-        auto &flushDwParams      = m_miItf->MHW_GETPAR_F(MI_FLUSH_DW)();
-        flushDwParams            = {};
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
-
-        // n1_lo = 0x00
-        auto &storeDataParams            = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
-        storeDataParams                  = {};
-        storeDataParams.pOsResource      = m_atomicScratchBuf.resAtomicScratchBuffer;
-        storeDataParams.dwResourceOffset = operand1Offset;
-        storeDataParams.dwValue          = 0x00;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(cmdBuffer));
-
-        // n2_lo = dwImageStatusMask
-        auto &copyMemMemParams       = m_miItf->MHW_GETPAR_F(MI_COPY_MEM_MEM)();
-        copyMemMemParams             = {};
-        copyMemMemParams.presSrc     = m_basicFeature->m_recycleBuf->GetBuffer(VdencBrcPakMmioBuffer, 0);
-        copyMemMemParams.dwSrcOffset = (sizeof(uint32_t) * 1);
-        copyMemMemParams.presDst     = m_atomicScratchBuf.resAtomicScratchBuffer;
-        copyMemMemParams.dwDstOffset = operand2Offset;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
-
-        // VCS_GPR0_Lo = ImageStatusCtrl
-        auto &registerMemParams           = m_miItf->MHW_GETPAR_F(MI_LOAD_REGISTER_MEM)();
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_basicFeature->m_recycleBuf->GetBuffer(VdencBrcPakMmioBuffer, 0);
-        registerMemParams.dwOffset        = (sizeof(uint32_t) * 0);
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister0LoOffset;  // VCS_GPR0_Lo
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        // Reset GPR4_Lo
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_atomicScratchBuf.resAtomicScratchBuffer;
-        registerMemParams.dwOffset        = zeroValueOffset;                                 //Offset 0, has value of 0.
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister4LoOffset;  // VCS_GPR4
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        // Make Flush DW call to make sure all previous work is done
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
-
-        // step-1: n2_lo = n2_lo & VCS_GPR0_Lo = dwImageStatusMask & ImageStatusCtrl
-        auto &atomicParams            = m_miItf->MHW_GETPAR_F(MI_ATOMIC)();
-        atomicParams                  = {};
-        atomicParams.pOsResource      = m_atomicScratchBuf.resAtomicScratchBuffer;
-        atomicParams.dwResourceOffset = operand2Offset;
-        atomicParams.dwDataSize       = sizeof(uint32_t);
-        atomicParams.Operation        = mhw::mi::MHW_MI_ATOMIC_AND;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_ATOMIC)(cmdBuffer));
-
-        // n3_lo = 0
-        storeDataParams                  = {};
-        storeDataParams.pOsResource      = m_atomicScratchBuf.resAtomicScratchBuffer;
-        storeDataParams.dwResourceOffset = operand3Offset;
-        storeDataParams.dwValue          = 0;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(cmdBuffer));
-
-        // Make Flush DW call to make sure all previous work is done
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
-
-        // GPR0_lo = n1_lo = 0
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_atomicScratchBuf.resAtomicScratchBuffer;
-        registerMemParams.dwOffset        = operand1Offset;
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister0LoOffset;  // VCS_GPR0
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        // Reset GPR4_Lo
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_atomicScratchBuf.resAtomicScratchBuffer;
-        registerMemParams.dwOffset        = zeroValueOffset;                                 //Offset 0, has value of 0.
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister4LoOffset;  // VCS_GPR4
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        // Make Flush DW call to make sure all previous work is done
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
-
-        // step-2: n2_lo == n1_lo ? 0 : n2_lo
-        // compare n1 vs n2. i.e. GRP0 vs. memory of operand2
-        atomicParams                  = {};
-        atomicParams.pOsResource      = m_atomicScratchBuf.resAtomicScratchBuffer;
-        atomicParams.dwResourceOffset = operand2Offset;
-        atomicParams.dwDataSize       = sizeof(uint32_t);
-        atomicParams.Operation        = mhw::mi::MHW_MI_ATOMIC_CMP;
-        atomicParams.bReturnData      = true;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_ATOMIC)(cmdBuffer));
-
-        // n2_hi = 1
-        storeDataParams                  = {};
-        storeDataParams.pOsResource      = m_atomicScratchBuf.resAtomicScratchBuffer;
-        storeDataParams.dwResourceOffset = operand2Offset + sizeof(uint32_t);
-        storeDataParams.dwValue          = 1;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(cmdBuffer));
-
-        // n3_hi = 1
-        storeDataParams                  = {};
-        storeDataParams.pOsResource      = m_atomicScratchBuf.resAtomicScratchBuffer;
-        storeDataParams.dwResourceOffset = operand3Offset + sizeof(uint32_t);
-        storeDataParams.dwValue          = 1;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(cmdBuffer));
-
-        // VCS_GPR0_Lo = n3_lo = 0
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_atomicScratchBuf.resAtomicScratchBuffer;
-        registerMemParams.dwOffset        = operand3Offset;
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister0LoOffset;  // VCS_GPR0_Lo
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        // GPR0_Hi = n2_hi = 1
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_atomicScratchBuf.resAtomicScratchBuffer;
-        registerMemParams.dwOffset        = operand2Offset + sizeof(uint32_t);               // update 1
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister0HiOffset;  // VCS_GPR0_Hi
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        // Reset GPR4_Lo and GPR4_Hi
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_atomicScratchBuf.resAtomicScratchBuffer;
-        registerMemParams.dwOffset        = zeroValueOffset;
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister4LoOffset;  // VCS_GPR4_Lo
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_atomicScratchBuf.resAtomicScratchBuffer;
-        registerMemParams.dwOffset        = zeroValueOffset;
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister4HiOffset;  // VCS_GPR4_Hi
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        // Make Flush DW call to make sure all previous work is done
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
-
-        // steop-3: n2 = (n2 == 0:1) ? 0:0 : n2      // uint64_t CMP
-        // If n2==0 (Lo) and 1 (Hi), covert n2 to 0 (Lo)and 0 (Hi), else no change.
-        // n2 == 0:1 means encoding completsion. the n2 memory will be updated with 0:0, otherwise, no change.
-        atomicParams                  = {};
-        atomicParams.pOsResource      = m_atomicScratchBuf.resAtomicScratchBuffer;
-        atomicParams.dwResourceOffset = operand2Offset;
-        atomicParams.dwDataSize       = sizeof(uint64_t);
-        atomicParams.Operation        = mhw::mi::MHW_MI_ATOMIC_CMP;
-        atomicParams.bReturnData      = true;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_ATOMIC)(cmdBuffer));
-
-        // Make Flush DW call to make sure all previous work is done
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
-
-        // VCS_GPR0_Lo = n3_hi = 1
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_atomicScratchBuf.resAtomicScratchBuffer;
-        registerMemParams.dwOffset        = operand3Offset + sizeof(uint32_t);
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister0LoOffset;  // VCS_GPR0_Lo
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        // Make Flush DW call to make sure all previous work is done
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
-
-        // step-4: n2_hi = n2_hi ^ VCS_GPR0_Lo = n2_hi ^ n3_hi
-        atomicParams                  = {};
-        atomicParams.pOsResource      = m_atomicScratchBuf.resAtomicScratchBuffer;
-        atomicParams.dwResourceOffset = operand2Offset + sizeof(uint32_t);
-        atomicParams.dwDataSize       = sizeof(uint32_t);
-        atomicParams.Operation        = mhw::mi::MHW_MI_ATOMIC_XOR;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_ATOMIC)(cmdBuffer));
-
-        // VCS_GPR0_Lo = n2_hi
-        registerMemParams                 = {};
-        registerMemParams.presStoreBuffer = m_atomicScratchBuf.resAtomicScratchBuffer;
-        registerMemParams.dwOffset        = operand2Offset + sizeof(uint32_t);
-        registerMemParams.dwRegister      = mmioRegisters->generalPurposeRegister0LoOffset;  // VCS_GPR0_Lo
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        // step-5: m_storeData = m_storeData + VCS_GPR0_Lo = m_storeData + n2_hi
-        // if not completed n2_hi should be 0, then m_storeData = m_storeData + 0
-        // if completed, n2_hi should be 1, then m_storeData = m_storeData + 1
-        auto &miLoadRegMemParams           = m_miItf->MHW_GETPAR_F(MI_LOAD_REGISTER_MEM)();
-        miLoadRegMemParams                 = {};
-        miLoadRegMemParams.presStoreBuffer = osResourceInline;
-        miLoadRegMemParams.dwOffset        = 0;
-        miLoadRegMemParams.dwRegister      = mmioRegisters->generalPurposeRegister4LoOffset;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(cmdBuffer));
-
-        mhw::mi::MHW_MI_ALU_PARAMS aluParams[4] = { 0 };
-        int               aluCount = 0;
-
-        aluCount = 0;
-
-        //load1 srca, reg1
-        aluParams[aluCount].AluOpcode = MHW_MI_ALU_LOAD;
-        aluParams[aluCount].Operand1  = MHW_MI_ALU_SRCA;
-        aluParams[aluCount].Operand2  = MHW_MI_ALU_GPREG0;
-        ++aluCount;
-        //load srcb, reg2
-        aluParams[aluCount].AluOpcode = MHW_MI_ALU_LOAD;
-        aluParams[aluCount].Operand1  = MHW_MI_ALU_SRCB;
-        aluParams[aluCount].Operand2  = MHW_MI_ALU_GPREG4;
-        ++aluCount;
-        //add
-        aluParams[aluCount].AluOpcode = MHW_MI_ALU_ADD;
-        ++aluCount;
-        //store reg1, accu
-        aluParams[aluCount].AluOpcode = MHW_MI_ALU_STORE;
-        aluParams[aluCount].Operand1  = MHW_MI_ALU_GPREG0;
-        aluParams[aluCount].Operand2  = MHW_MI_ALU_ACCU;
-        ++aluCount;
-
-        auto &miMathParams           = m_miItf->MHW_GETPAR_F(MI_MATH)();
-        miMathParams                 = {};
-        miMathParams.dwNumAluParams  = aluCount;
-        miMathParams.pAluPayload     = aluParams;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_MATH)(cmdBuffer));
-        ENCODE_CHK_STATUS_RETURN(Mos_AddCommand(
-            cmdBuffer,
-            &miMathParams.pAluPayload[0],
-            sizeof(mhw::mi::MHW_MI_ALU_PARAMS) * miMathParams.dwNumAluParams));
-
-        auto &miStoreRegMemParams           = m_miItf->MHW_GETPAR_F(MI_STORE_REGISTER_MEM)();
-        miStoreRegMemParams                 = {};
-        miStoreRegMemParams.presStoreBuffer = osResourceInline;
-        miStoreRegMemParams.dwOffset        = 0;
-        miStoreRegMemParams.dwRegister      = mmioRegisters->generalPurposeRegister0LoOffset;
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(cmdBuffer));
-
-        // Make Flush DW call to make sure all previous work is done
-        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
-
-        return MOS_STATUS_SUCCESS;
-    }
-
     MOS_STATUS Av1VdencPktXe_M_Base::CalculateAvpPictureStateCommandSize(uint32_t * commandsSize, uint32_t * patchListSize)
     {
         ENCODE_FUNC_CALL();
 
         MHW_VDBOX_STATE_CMDSIZE_PARAMS_G12 stateCmdSizeParams;
         MOS_ZeroMemory(&stateCmdSizeParams, sizeof(MHW_VDBOX_STATE_CMDSIZE_PARAMS_G12));
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(
+        ENCODE_CHK_STATUS_RETURN(
             m_hwInterface->GetAvpStateCommandSize(
                 CODECHAL_ENCODE_MODE_AV1,
                 commandsSize,
@@ -1164,13 +955,13 @@ namespace encode
         uint32_t avpTilePatchListSize    = 0;
 
         // Picture Level Commands
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(CalculateAvpPictureStateCommandSize(&avpPictureStatesSize, &avpPicturePatchListSize));
+        ENCODE_CHK_STATUS_RETURN(CalculateAvpPictureStateCommandSize(&avpPictureStatesSize, &avpPicturePatchListSize));
 
         m_pictureStatesSize += avpPictureStatesSize;
         m_picturePatchListSize += avpPicturePatchListSize;
 
         // Tile Level Commands
-        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_hwInterface->GetAvpPrimitiveCommandSize(
+        ENCODE_CHK_STATUS_RETURN(m_hwInterface->GetAvpPrimitiveCommandSize(
             CODECHAL_ENCODE_MODE_AV1,
             &avpTileStatesSize,
             &avpTilePatchListSize));
