@@ -34,6 +34,8 @@
 #include "mhw_impl.h"
 #include "mhw_mmio_xe_lpm_plus.h"
 
+#define MHW_MI_TEE_DEFAULT_WATCHDOG_THRESHOLD_IN_MS 200
+
 namespace mhw
 {
 namespace mi
@@ -259,7 +261,9 @@ public:
         }
         MOS_GPU_CONTEXT gpuContext = this->m_osItf->pfnGetGpuContext(this->m_osItf);
 
-        if ((MOS_VCS_ENGINE_USED(gpuContext) || MOS_VECS_ENGINE_USED(gpuContext)) &&
+        if ((MOS_VCS_ENGINE_USED(gpuContext) || 
+             MOS_VECS_ENGINE_USED(gpuContext) || 
+             MOS_TEECS_ENGINE_USED(gpuContext)) &&
             (reg >= M_MMIO_MEDIA_LOW_OFFSET && reg < M_MMIO_MEDIA_HIGH_OFFSET))
         {
             reg &= M_MMIO_MAX_RELATIVE_OFFSET;
@@ -268,6 +272,22 @@ public:
         return false;
     }
 
+    MOS_STATUS SetWatchdogTimerThresholdForTee()
+    {
+        MHW_FUNCTION_ENTER;
+        MHW_MI_CHK_NULL(this->m_osItf);
+        if (this->m_osItf->bMediaReset == false ||
+            this->m_osItf->umdMediaResetEnable == false)
+        {
+            return MOS_STATUS_SUCCESS;
+        }
+
+        MediaResetParam.watchdogCountThreshold = MHW_MI_TEE_DEFAULT_WATCHDOG_THRESHOLD_IN_MS;
+        GetWatchdogThreshold(this->m_osItf);
+
+        return MOS_STATUS_SUCCESS;
+    }
+
     MOS_STATUS SetWatchdogTimerThreshold(uint32_t frameWidth, uint32_t frameHeight, bool isEncoder) override
     {
         MEDIA_WA_TABLE *waTable = nullptr;
@@ -369,6 +389,11 @@ public:
             MediaResetParam.watchdogCountCtrlOffset      = WATCHDOG_COUNT_CTRL_OFFSET_VECS_XE_LPM_PLUS;
             MediaResetParam.watchdogCountThresholdOffset = WATCHDOG_COUNT_THRESTHOLD_OFFSET_VECS_XE_LPM_PLUS;
             break;
+            // TEE
+        case MOS_GPU_CONTEXT_TEE:
+            MediaResetParam.watchdogCountCtrlOffset      = WATCHDOG_COUNT_CTRL_OFFSET_TEECS_XE_LPM_PLUS;
+            MediaResetParam.watchdogCountThresholdOffset = WATCHDOG_COUNT_THRESTHOLD_OFFSET_TEECS_XE_LPM_PLUS;
+            break;
             // Default
         default:
             break;
@@ -402,6 +427,10 @@ public:
         //Configure Watchdog timer Threshold
         auto& par = MHW_GETPAR_F(MI_LOAD_REGISTER_IMM)();
         par = {};
+        if (gpuContext == MOS_GPU_CONTEXT_TEE)
+        {
+            MHW_MI_CHK_STATUS(SetWatchdogTimerThresholdForTee());
+        }
         par.dwData     = MHW_MI_WATCHDOG_COUNTS_PER_MILLISECOND * MediaResetParam.watchdogCountThreshold *
             (this->m_osItf->bSimIsActive ? 2 : 1);
         par.dwRegister = MediaResetParam.watchdogCountThresholdOffset;
