@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2021, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -153,28 +153,50 @@ namespace decode
         return MOS_STATUS_SUCCESS;
     }
 
-    MOS_STATUS Av1BasicFeature::ErrorDetectAndConceal()
+    MOS_STATUS Av1BasicFeature::CheckProfileAndSubsampling()
     {
-        DECODE_FUNC_CALL()
-        DECODE_CHK_NULL(m_av1PicParams);
+        DECODE_FUNC_CALL();
 
         // Profile and subsampling
         if (m_av1PicParams->m_seqInfoFlags.m_fields.m_monoChrome ||
             m_av1PicParams->m_profile != 0 ||
-            !(m_av1PicParams->m_seqInfoFlags.m_fields.m_subsamplingX ==1 &&
+            !(m_av1PicParams->m_seqInfoFlags.m_fields.m_subsamplingX == 1 &&
                 m_av1PicParams->m_seqInfoFlags.m_fields.m_subsamplingY == 1))
         {
             DECODE_ASSERTMESSAGE("Only 4:2:0 8bit and 10bit are supported!");
             return MOS_STATUS_INVALID_PARAMETER;
         }
 
+        return MOS_STATUS_SUCCESS;
+    }
+
+    MOS_STATUS Av1BasicFeature::ErrorDetectAndConceal()
+    {
+        DECODE_FUNC_CALL()
+        DECODE_CHK_NULL(m_av1PicParams);
+
+        DECODE_CHK_STATUS(CheckProfileAndSubsampling());
+
+        // Frame Width/Frame Height, valid range is [15, 16383]
+        if (m_av1PicParams->m_frameWidthMinus1 < 15 || m_av1PicParams->m_frameHeightMinus1 < 15)
+        {
+            DECODE_ASSERTMESSAGE("Frame Width/Height is invalid, out of [15, 16383].");
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
+
+        if (!m_av1PicParams->m_seqInfoFlags.m_fields.m_enableOrderHint &&
+            (m_av1PicParams->m_orderHint != 0))
+        {
+            DECODE_ASSERTMESSAGE("orderHint Conflict with AV1 Spec!");
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
         if(m_av1PicParams->m_picInfoFlags.m_fields.m_allowIntrabc &&
             (!(m_av1PicParams->m_picInfoFlags.m_fields.m_frameType == keyFrame ||
                 m_av1PicParams->m_picInfoFlags.m_fields.m_frameType == intraOnlyFrame) ||
                 !m_av1PicParams->m_picInfoFlags.m_fields.m_allowScreenContentTools ||
                 m_av1PicParams->m_picInfoFlags.m_fields.m_useSuperres))
         {
-            DECODE_ASSERTMESSAGE("Conflict with AV1 Spec.");
+            DECODE_ASSERTMESSAGE("Superres use Conflict with AV1 Spec.");
             return MOS_STATUS_INVALID_PARAMETER;
         }
 
@@ -346,6 +368,16 @@ namespace decode
             m_av1PicParams->m_loopRestorationFlags.m_value = 0;
         }
 
+        // LRU Luma Size cannot < Superblock Size. If Superblock Size is 128x128, LRU Luma Size cannot be 64x64.
+        if (m_av1PicParams->m_seqInfoFlags.m_fields.m_use128x128Superblock)
+        {
+            if (m_av1PicParams->m_loopRestorationFlags.m_fields.m_lrUnitShift == 0)
+            {
+                DECODE_ASSERTMESSAGE("Superblock use Conflict with AV1 Spec!");
+                m_av1PicParams->m_loopRestorationFlags.m_value = 0;
+            }
+        }
+
         // Error Concealment for DeltaLF and DeltaQ
         if (m_av1PicParams->m_baseQindex == 0)
         {
@@ -379,6 +411,12 @@ namespace decode
             memset(&m_av1PicParams->m_filmGrainParams, 0, sizeof(CodecAv1FilmGrainParams));
         }
 
+        // Error Concealment for Reference List
+        if (m_av1PicParams->m_picInfoFlags.m_fields.m_frameType != keyFrame && m_av1PicParams->m_picInfoFlags.m_fields.m_frameType != intraOnlyFrame)
+        {
+            DECODE_CHK_STATUS(m_refFrames.ErrorConcealment(*m_av1PicParams));
+        }
+
         return MOS_STATUS_SUCCESS;
     }
 
