@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2022, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -34,7 +34,6 @@
 #include "encode_av1_basic_feature.h"
 #include "encode_status_report.h"
 #include "codec_def_encode_av1.h"
-#include "mhw_vdbox_avp_interface.h"
 #include "mhw_vdbox_vdenc_itf.h"
 #include "mhw_vdbox_avp_itf.h"
 #include "mhw_mi_itf.h"
@@ -47,6 +46,24 @@ namespace encode
 //(4096*4096)/64 *16 (streamout0) + 1MB(streamout 1). there is scope to reduce streamout1 size. Need to check with HW team.
 // 8K is just an estimation
 
+//!
+//! \struct AtomicScratchBuffer
+//! \brief  The sturct of Atomic Scratch Buffer
+//!
+struct AtomicScratchBufferAv1
+{
+    PMOS_RESOURCE resAtomicScratchBuffer;  //!> Handle of eStatus buffer
+    uint32_t     *pData;                   //!> Pointer of the buffer of actual data
+    uint16_t      encodeUpdateIndex;       //!> used for VDBOX update encode status
+    uint16_t      tearDownIndex;           //!> Reserved for future extension
+    uint32_t      zeroValueOffset;         //!> Store the result of the ATOMIC_CMP
+    uint32_t      operand1Offset;          //!> Operand 1 of the ATOMIC_CMP
+    uint32_t      operand2Offset;          //!> Operand 2 of the ATOMIC_CMP
+    uint32_t      operand3Offset;          //!> Copy of the operand 1
+    uint32_t      size;                    //!> Size of the buffer
+    uint32_t      operandSetSize;          //!> Size of Operand set
+};
+
 inline uint32_t GetUseInterVsSkipSADWinner(uint32_t MrgCand8x8DepEn, uint32_t MrgCand16x16DepEn)
 {
     uint32_t useInterVsSkipSADWinner = 0;
@@ -74,7 +91,7 @@ inline uint32_t GetUseInterVsSkipSADWinner(uint32_t MrgCand8x8DepEn, uint32_t Mr
 class Av1VdencPkt : public CmdPacket, public MediaStatusReportObserver, public mhw::vdbox::vdenc::Itf::ParSetting, public mhw::vdbox::avp::Itf::ParSetting
 {
 public:
-    Av1VdencPkt(MediaPipeline* pipeline, MediaTask* task, CodechalHwInterface* hwInterface);
+    Av1VdencPkt(MediaPipeline* pipeline, MediaTask* task, CodechalHwInterfaceNext* hwInterface);
     virtual ~Av1VdencPkt() {}
 
     //!
@@ -167,6 +184,8 @@ protected:
 
     MOS_STATUS AddCondBBEndFor2ndPass(MOS_COMMAND_BUFFER &cmdBuffer);
 
+    virtual MOS_STATUS UpdateStatusReport(uint32_t srType, MOS_COMMAND_BUFFER *cmdBuffer) override;
+
     //!
     //! \brief  Calculate Command Buffer Size
     //!
@@ -222,26 +241,13 @@ protected:
         EncodeStatusMfx        *encodeStatusMfx,
         EncodeStatusReportData *statusReportData);
 
-    virtual MOS_STATUS PopulateParFileParams(
-        const CODEC_AV1_ENCODE_SEQUENCE_PARAMS *  seqParams,
-        const CODEC_AV1_ENCODE_PICTURE_PARAMS *   picParams,
-        const uint32_t                            numTileGroups,
-        const CODEC_AV1_ENCODE_TILE_GROUP_PARAMS *tileGroupParams,
-        const MHW_BATCH_BUFFER *                  batchBuffer);
-
-    virtual MOS_STATUS InitParParams();
-
-    MOS_STATUS PopulateParFileParams();
-
-    virtual MOS_STATUS DumpSeqParFile();
 #endif  // USE_CODECHAL_DEBUG_TOOL
 
     Av1VdencPipeline *m_pipeline = nullptr;
 
     // Interfaces
     EncodeAllocator                 *m_allocator        = nullptr;
-    PMOS_INTERFACE                   m_osInterface      = nullptr;
-    CodechalHwInterface             *m_hwInterface      = nullptr;
+    CodechalHwInterfaceNext         *m_hwInterface      = nullptr;
     CodechalHwInterfaceNext         *m_hwInterfaceNext  = nullptr;
     EncodeMemComp                   *m_mmcState         = nullptr;
     Av1BasicFeature                 *m_basicFeature     = nullptr;              //!< Encode parameters used in each frame
@@ -258,9 +264,7 @@ protected:
 
     mutable uint8_t m_curAvpSurfStateId = 0;
 
-#if USE_CODECHAL_DEBUG_TOOL
-    EncodeAv1Par *m_av1Par = nullptr;
-#endif  // USE_CODECHAL_DEBUG_TOOL
+    AtomicScratchBufferAv1 m_atomicScratchBuf = {};  //!< Stores atomic operands and result
 
     bool m_vdencPakObjCmdStreamOutEnabled               = false;    //!< Pakobj stream out enable flag
     PMOS_RESOURCE m_resCumulativeCuCountStreamoutBuffer = nullptr;  //!< Cumulative CU count stream out buffer
@@ -284,7 +288,7 @@ protected:
     MOS_STATUS SetSurfaceState(
         PMHW_VDBOX_SURFACE_PARAMS surfaceStateParams);
 
-    void SetPerfTag(uint16_t type, uint16_t mode, uint16_t picCodingType);
+    void SetPerfTag();
     MOS_STATUS AddForceWakeup(MOS_COMMAND_BUFFER &cmdBuffer);
     MOS_STATUS SendPrologCmds(MOS_COMMAND_BUFFER &cmdBuffer);
     MOS_STATUS SetRowstoreCachingOffsets();
@@ -293,6 +297,8 @@ protected:
 
     MOS_STATUS ReadPakMmioRegisters(PMOS_COMMAND_BUFFER cmdBuf, bool firstTile);
 
+    MOS_STATUS ReadPakMmioRegistersAtomic(PMOS_COMMAND_BUFFER cmdBuf);
+
     MHW_SETPAR_DECL_HDR(VD_PIPELINE_FLUSH);
 
     MHW_SETPAR_DECL_HDR(VDENC_PIPE_MODE_SELECT);
@@ -313,7 +319,7 @@ protected:
 
     virtual MOS_STATUS GetAvpPrimitiveCommandsDataSize(uint32_t *commandsSize, uint32_t *patchListSize) const;
 
-MEDIA_CLASS_DEFINE_END(Av1VdencPkt)
+MEDIA_CLASS_DEFINE_END(encode__Av1VdencPkt)
 };
 
 }  // namespace encode
