@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -32,7 +32,7 @@
 namespace encode {
 
 Av1VdencPipeline::Av1VdencPipeline(
-    CodechalHwInterface *   hwInterface,
+    CodechalHwInterfaceNext *   hwInterface,
     CodechalDebugInterface *debugInterface)
     : Av1Pipeline(hwInterface, debugInterface)
 {
@@ -43,12 +43,25 @@ MOS_STATUS Av1VdencPipeline::Initialize(void *settings)
 {
     ENCODE_FUNC_CALL();
     ENCODE_CHK_STATUS_RETURN(Av1Pipeline::Initialize(settings));
+
+    // Init hwInterface
+    CodechalSetting *codecSettings = (CodechalSetting *)settings;
+    ENCODE_CHK_NULL_RETURN(m_hwInterface);
+    ENCODE_CHK_STATUS_RETURN(m_hwInterface->Initialize(codecSettings));
+
+    ENCODE_CHK_STATUS_RETURN(InitMmcState());
+
+    ENCODE_CHK_STATUS_RETURN(GetSystemVdboxNumber());
+
     return MOS_STATUS_SUCCESS;
 }
 
 MOS_STATUS Av1VdencPipeline::Uninitialize()
 {
     ENCODE_FUNC_CALL();
+
+    MOS_Delete(m_mmcState);
+    
     return Av1Pipeline::Uninitialize();
 }
 
@@ -57,6 +70,12 @@ MOS_STATUS Av1VdencPipeline::UserFeatureReport()
     ENCODE_FUNC_CALL();
     ENCODE_CHK_STATUS_RETURN(Av1Pipeline::UserFeatureReport());
 
+    ReportUserSetting(
+        m_userSettingPtr,
+        "AV1 Encode Mode",
+        m_codecFunction,
+        MediaUserSetting::Group::Sequence);
+
 #if (_DEBUG || _RELEASE_INTERNAL)
     ReportUserSettingForDebug(
         m_userSettingPtr,
@@ -84,23 +103,6 @@ MOS_STATUS Av1VdencPipeline::Prepare(void *params)
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS Av1VdencPipeline::ContextSwitchBack()
-{
-    ENCODE_FUNC_CALL();
-
-    ENCODE_CHK_NULL_RETURN(m_scalPars);
-
-    m_scalPars->IsContextSwitchBack = true;
-    m_mediaContext->SwitchContext(VdboxEncodeFunc, m_scalPars.get(), &m_scalability);
-    m_scalPars->IsContextSwitchBack = false;
-
-    ENCODE_CHK_NULL_RETURN(m_scalability);
-
-    m_scalability->SetPassNumber(m_featureManager->GetNumPass());
-
-    return MOS_STATUS_SUCCESS;
-}
-
 MOS_STATUS Av1VdencPipeline::ActivateVdencVideoPackets()
 {
     ENCODE_FUNC_CALL();
@@ -132,6 +134,11 @@ MOS_STATUS Av1VdencPipeline::ActivateVdencVideoPackets()
             ENCODE_CHK_STATUS_RETURN(ActivatePacket(Av1VdencPacket, immediateSubmit, curPass, curPipe, GetPipeNum()));
         }
 
+        if ((basicFeature->m_enableTileStitchByHW || !basicFeature -> m_enableSWStitching || brcFeature->IsBRCEnabled()) && m_dualEncEnable)
+        {
+            ENCODE_CHK_STATUS_RETURN(ActivatePacket(Av1PakIntegrate, immediateSubmit, curPass, 0));
+        }
+
         if (!basicFeature->m_enableSWBackAnnotation)
         {
             ENCODE_CHK_STATUS_RETURN(ActivatePacket(Av1BackAnnotation, immediateSubmit, curPass, 0));
@@ -168,8 +175,16 @@ MOS_STATUS Av1VdencPipeline::SwitchContext(uint8_t outputChromaFormat, uint16_t
     m_scalPars->enableVE = MOS_VE_SUPPORTED(m_osInterface);
 
     //force to disable scalability for AV1 VDENC
-    m_scalPars->numVdbox = 1;
-    m_scalPars->forceMultiPipe = false;
+    if(m_dualEncEnable)
+    {
+        m_scalPars->numVdbox = m_numVdbox;
+        m_scalPars->forceMultiPipe = true;
+    }
+    else
+    {
+        m_scalPars->numVdbox = 1;
+        m_scalPars->forceMultiPipe = false;
+    }
 
     m_scalPars->outputChromaFormat = outputChromaFormat;
 
