@@ -23,11 +23,12 @@
 //! \file     encode_pak_integrate_packet.cpp
 //! \brief    Defines the interface for pak integrate packet
 //!
+#include "mos_defs.h"
 #include "encode_pak_integrate_packet.h"
 #include "mhw_vdbox.h"
 #include "encode_hevc_brc.h"
 #include "encode_status_report_defs.h"
-#include "mos_defs.h"
+#include "mos_os_cp_interface_specific.h"
 
 namespace encode {
     MOS_STATUS HevcPakIntegratePkt::Init()
@@ -37,7 +38,7 @@ namespace encode {
         m_basicFeature = dynamic_cast<HevcBasicFeature *>(m_featureManager->GetFeature(HevcFeatureIDs::basicFeature));
         ENCODE_CHK_NULL_RETURN(m_basicFeature);
 
-        ENCODE_CHK_STATUS_RETURN(EncodeHucBasic::Init());
+        ENCODE_CHK_STATUS_RETURN(EncodeHucPkt::Init());
 
         ENCODE_CHK_NULL_RETURN(m_hwInterface);
         m_osInterface  = m_hwInterface->GetOsInterface();
@@ -57,7 +58,7 @@ namespace encode {
 
     MOS_STATUS HevcPakIntegratePkt::AllocateResources()
     {
-        ENCODE_CHK_STATUS_RETURN(EncodeHucBasic::AllocateResources());
+        ENCODE_CHK_STATUS_RETURN(EncodeHucPkt::AllocateResources());
 
         // Only needed when tile & BRC is enabled, but the size is not changing at frame level
         if (m_resHucPakStitchDmemBuffer[0][0] == nullptr)
@@ -72,6 +73,7 @@ namespace encode {
             allocParamsForBufferLinear.Format   = Format_Buffer;
             allocParamsForBufferLinear.dwBytes  = MOS_ALIGN_CEIL(sizeof(HucPakIntegrateDmem), CODECHAL_CACHELINE_SIZE);
             allocParamsForBufferLinear.pBufName = "PAK Stitch Dmem Buffer";
+            allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_NOCACHE;
             auto numOfPasses                    = CODECHAL_VDENC_BRC_NUM_OF_PASSES;
 
             for (auto k = 0; k < CODECHAL_ENCODE_RECYCLED_BUFFER_NUM; k++)
@@ -87,6 +89,7 @@ namespace encode {
                 // HuC stitching data buffer
                 allocParamsForBufferLinear.dwBytes  = MOS_ALIGN_CEIL(sizeof(HucCommandData), CODECHAL_PAGE_SIZE);
                 allocParamsForBufferLinear.pBufName = "HEVC HuC Stitch Data Buffer";
+                allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_CACHE;
                 MOS_RESOURCE *allocatedBuffer       = nullptr;
                 for (auto i = 0; i < CODECHAL_ENCODE_RECYCLED_BUFFER_NUM; ++i)
                 {
@@ -143,6 +146,9 @@ namespace encode {
         bool firstTaskInPhase = packetPhase & firstPacket;
         bool requestProlog = !m_pipeline->IsSingleTaskPhaseSupported() || firstTaskInPhase;
 
+        uint16_t perfTag = CODECHAL_ENCODE_PERFTAG_CALL_PAK_KERNEL;
+        SetPerfTag(perfTag, (uint16_t)m_basicFeature->m_mode, m_basicFeature->m_pictureCodingType);
+
         auto brcFeature = dynamic_cast<HEVCEncodeBRC *>(m_featureManager->GetFeature(HevcFeatureIDs::hevcBrcFeature));
         ENCODE_CHK_NULL_RETURN(brcFeature);
         m_vdencHucUsed = brcFeature->IsVdencHucUsed();
@@ -150,6 +156,11 @@ namespace encode {
         bool isTileReplayEnabled = false;
         RUN_FEATURE_INTERFACE_RETURN(HevcEncodeTile, FeatureIDs::encodeTile, IsTileReplayEnabled, isTileReplayEnabled);
 
+        MediaPerfProfiler *perfProfiler = MediaPerfProfiler::Instance();
+        ENCODE_CHK_NULL_RETURN(perfProfiler);
+        ENCODE_CHK_STATUS_RETURN(perfProfiler->AddPerfCollectStartCmd(
+            (void *)m_pipeline, m_osInterface, m_miItf, commandBuffer));
+
         if (m_vdencHucUsed || (m_basicFeature->m_enableTileStitchByHW && (isTileReplayEnabled || m_pipeline->GetPipeNum() > 1)))
         {
             // Huc basic
@@ -166,7 +177,7 @@ namespace encode {
             storeDataParams                  = {};
             storeDataParams.pOsResource      = osResource;
             storeDataParams.dwResourceOffset = offset;
-            storeDataParams.dwValue          = m_hwInterface->GetHucInterface()->GetHucStatusReEncodeMask();
+            storeDataParams.dwValue          = m_hwInterface->GetHucInterfaceNext()->GetHucStatusReEncodeMask();
             ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(commandBuffer));
 
             // store HUC_STATUS register
@@ -197,7 +208,7 @@ namespace encode {
         ENCODE_CHK_STATUS_RETURN(EndStatusReport(statusReportMfx, commandBuffer));
         if (false == m_pipeline->IsFrameTrackingEnabled())
         {
-            ENCODE_CHK_STATUS_RETURN(UpdateStatusReport(statusReportGlobalCount, commandBuffer));
+            ENCODE_CHK_STATUS_RETURN(UpdateStatusReportNext(statusReportGlobalCount, commandBuffer));
         }
         CODECHAL_DEBUG_TOOL(
             if (m_mmcState) {
@@ -244,7 +255,7 @@ namespace encode {
         }
         ENCODE_CHK_STATUS_RETURN(MediaPacket::EndStatusReportNext(srType, cmdBuffer));
 
-        MediaPerfProfilerNext *perfProfiler = MediaPerfProfilerNext::Instance();
+        MediaPerfProfiler *perfProfiler = MediaPerfProfiler::Instance();
         ENCODE_CHK_NULL_RETURN(perfProfiler);
         ENCODE_CHK_STATUS_RETURN(perfProfiler->AddPerfCollectEndCmd(
             (void *)m_pipeline, m_osInterface, m_miItf, cmdBuffer));
@@ -266,8 +277,8 @@ namespace encode {
         ENCODE_CHK_NULL_RETURN(statusReport);
         ENCODE_CHK_NULL_RETURN(m_hwInterface);
 
-        MOS_RESOURCE *osResource;
-        uint32_t      offset;
+        MOS_RESOURCE *osResource = nullptr;
+        uint32_t      offset = 0;
 
         EncodeStatusReadParams params;
         MOS_ZeroMemory(&params, sizeof(params));
@@ -367,7 +378,7 @@ namespace encode {
         ENCODE_FUNC_CALL();
 
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-        if (vdboxIndex > m_hwInterface->GetMfxInterface()->GetMaxVdboxIndex())
+        if (vdboxIndex > m_hwInterface->GetMaxVdboxIndex())
         {
             //ENCODE_ASSERTMESSAGE("ERROR - vdbox index exceed the maximum");
             eStatus = MOS_STATUS_INVALID_PARAMETER;
@@ -384,31 +395,28 @@ namespace encode {
         uint32_t hucPatchListSize = 0;
         MHW_VDBOX_STATE_CMDSIZE_PARAMS stateCmdSizeParams;
 
-        if (m_hwInterface->m_hwInterfaceNext)
-        {
-            stateCmdSizeParams.uNumStoreDataImm = 2;
-            stateCmdSizeParams.uNumStoreReg     = 4;
-            stateCmdSizeParams.uNumMfxWait      = 11;
-            stateCmdSizeParams.uNumMiCopy       = 5;
-            stateCmdSizeParams.uNumMiFlush      = 2;
-            stateCmdSizeParams.uNumVdPipelineFlush  = 1;
-            stateCmdSizeParams.bPerformHucStreamOut = true;
-            ENCODE_CHK_STATUS_RETURN(m_hwInterface->m_hwInterfaceNext->GetHucStateCommandSize(
-                m_basicFeature->m_mode, (uint32_t*)&hucCommandsSize, (uint32_t*)&hucPatchListSize, &stateCmdSizeParams));
+        stateCmdSizeParams.uNumStoreDataImm = 2;
+        stateCmdSizeParams.uNumStoreReg     = 4;
+        stateCmdSizeParams.uNumMfxWait      = 11;
+        stateCmdSizeParams.uNumMiCopy       = 5;
+        stateCmdSizeParams.uNumMiFlush      = 2;
+        stateCmdSizeParams.uNumVdPipelineFlush  = 1;
+        stateCmdSizeParams.bPerformHucStreamOut = true;
+        ENCODE_CHK_STATUS_RETURN(m_hwInterface->GetHucStateCommandSize(
+            m_basicFeature->m_mode, (uint32_t*)&hucCommandsSize, (uint32_t*)&hucPatchListSize, &stateCmdSizeParams));
 
-            bool isTileReplayEnabled = false;
-            RUN_FEATURE_INTERFACE_RETURN(HevcEncodeTile, FeatureIDs::encodeTile, IsTileReplayEnabled, isTileReplayEnabled);
-            if (m_basicFeature->m_enableTileStitchByHW && (isTileReplayEnabled || m_pipeline->GetPipeNum() > 1))
-            {
-                uint32_t maxSize = 0;
-                uint32_t patchListMaxSize = 0;
-                ENCODE_CHK_NULL_RETURN(m_hwInterface);
-                ENCODE_CHK_NULL_RETURN(m_hwInterface->GetCpInterface());
-                MhwCpInterface *cpInterface = m_hwInterface->GetCpInterface();
-                cpInterface->GetCpStateLevelCmdSize(maxSize, patchListMaxSize);
-                hucCommandsSize     += maxSize;
-                hucPatchListSize    += patchListMaxSize;
-            }
+        bool isTileReplayEnabled = false;
+        RUN_FEATURE_INTERFACE_RETURN(HevcEncodeTile, FeatureIDs::encodeTile, IsTileReplayEnabled, isTileReplayEnabled);
+        if (m_basicFeature->m_enableTileStitchByHW && (isTileReplayEnabled || m_pipeline->GetPipeNum() > 1))
+        {
+            uint32_t maxSize = 0;
+            uint32_t patchListMaxSize = 0;
+            ENCODE_CHK_NULL_RETURN(m_hwInterface);
+            ENCODE_CHK_NULL_RETURN(m_hwInterface->GetCpInterface());
+            MhwCpInterface *cpInterface = m_hwInterface->GetCpInterface();
+            cpInterface->GetCpStateLevelCmdSize(maxSize, patchListMaxSize);
+            hucCommandsSize     += maxSize;
+            hucPatchListSize    += patchListMaxSize;
         }
 
         commandBufferSize = hucCommandsSize;
@@ -520,7 +528,7 @@ namespace encode {
                     if (0 == sliceNumInTile)
                     {
                         // One tile must have at least one slice
-                        CODECHAL_ENCODE_ASSERT(false);
+                        ENCODE_ASSERT(false);
                         eStatus = MOS_STATUS_INVALID_PARAMETER;
                         break;
                     }
