@@ -27,17 +27,20 @@
 #ifndef __MEDIA_DEBUG_INTERFACE_H__
 #define __MEDIA_DEBUG_INTERFACE_H__
 
-#if (_DEBUG || _RELEASE_INTERNAL)
+#if ((_DEBUG || _RELEASE_INTERNAL))
 #define USE_MEDIA_DEBUG_TOOL 1
 #define MEDIA_DEBUG_TOOL(expr) expr;
 
-#include "BRCIF.h"
 #include "mhw_utilities.h"
 #include "mhw_state_heap.h"
+#include "mhw_cp_interface.h"
 #include "media_debug_config_manager.h"
 #include "media_debug_utils.h"
+#include "media_copy_wrapper.h"
 #include <sstream>
 #include <fstream>
+#include <functional>
+
 using GoldenReferences = std::vector<std::vector<uint32_t>>;
 class MediaDebugInterface
 {
@@ -47,89 +50,11 @@ public:
 
     MOS_STATUS InitDumpLocation();
 
-    bool DumpIsEnabled(
-        const char *           attr,
-        MEDIA_DEBUG_STATE_TYPE mediaState = CODECHAL_NUM_MEDIA_STATES);
-
-    const char *CreateFileName(
-        const char *funcName,
-        const char *bufType,
-        const char *extType);
-
     MOS_STATUS SetOutputFilePath();
 
-    MOS_STATUS DumpStringStream(
-        std::stringstream& ss,
-        const char*        bufferName,
-        const char*        attrName);
-
-    MOS_STATUS DumpCmdBuffer(
-        PMOS_COMMAND_BUFFER    cmdBuffer,
-        MEDIA_DEBUG_STATE_TYPE mediaState,
-        const char *           cmdName = nullptr);
-
-    MOS_STATUS Dump2ndLvlBatch(
-        PMHW_BATCH_BUFFER      batchBuffer,
-        MEDIA_DEBUG_STATE_TYPE mediaState,
-        const char *           batchName = nullptr);
-
-    MOS_STATUS DumpCurbe(
-        MEDIA_DEBUG_STATE_TYPE mediaState,
-        PMHW_KERNEL_STATE      kernelState);
-
-    MOS_STATUS DumpMDFCurbe(
-        MEDIA_DEBUG_STATE_TYPE mediaState,
-        uint8_t *              curbeBuffer,
-        uint32_t               curbeSize);
-
-    MOS_STATUS DumpKernelRegion(
-        MEDIA_DEBUG_STATE_TYPE mediaState,
-        MHW_STATE_HEAP_TYPE    stateHeapType,
-        PMHW_KERNEL_STATE      kernelState);
-
-    virtual MOS_STATUS DumpRgbDataOnYUVSurface(
-        PMOS_SURFACE           surface,
-        const char *           attrName,
-        const char *           surfName,
-        MEDIA_DEBUG_STATE_TYPE mediaState = CODECHAL_NUM_MEDIA_STATES,
-        uint32_t               width_in   = 0,
-        uint32_t               height_in  = 0);
-
-    virtual MOS_STATUS DumpYUVSurface(
-        PMOS_SURFACE           surface,
-        const char *           attrName,
-        const char *           surfName,
-        MEDIA_DEBUG_STATE_TYPE mediaState = CODECHAL_NUM_MEDIA_STATES,
-        uint32_t               width_in   = 0,
-        uint32_t               height_in  = 0);
-
     virtual MOS_STATUS DumpUncompressedYUVSurface(
         PMOS_SURFACE           surface);
 
-    MOS_STATUS DumpBuffer(
-        PMOS_RESOURCE          resource,
-        const char *           attrName,
-        const char *           bufferName,
-        uint32_t               size,
-        uint32_t               offset = 0,
-        MEDIA_DEBUG_STATE_TYPE mediaState = CODECHAL_NUM_MEDIA_STATES);
-
-    MOS_STATUS DumpSurface(
-        PMOS_SURFACE           surface,
-        const char *           attrName,
-        const char *           surfaceName,
-        MEDIA_DEBUG_STATE_TYPE mediaState = CODECHAL_NUM_MEDIA_STATES);
-
-    MOS_STATUS DumpData(
-        void       *data,
-        uint32_t   size,
-        const char *attrName,
-        const char *bufferName);
-
-    MOS_STATUS DumpSurfaceInfo(
-        PMOS_SURFACE surface,
-        const char*  surfaceName);
-
     MOS_STATUS DumpMosSpecificResourceInfoToOfs(
         PMOS_RESOURCE  pOsResource,
         std::ofstream &ofs);
@@ -157,22 +82,14 @@ public:
 
     virtual MOS_STATUS LoadGoldenReference();
 
-    virtual MOS_STATUS DetectCorruptionSw(CodechalDecode *pCodechalDecode, std::vector<MOS_RESOURCE> &vResource, PMOS_RESOURCE frameCntRes, uint8_t *buf, uint32_t &size, uint32_t frameNum) { return MOS_STATUS_SUCCESS; };
-
-    virtual MOS_STATUS DetectCorruptionHw(CodechalHwInterface *hwInterface, PMOS_RESOURCE frameCntRes, uint32_t curIdx, uint32_t frameCrcOffset, std::vector<MOS_RESOURCE> &vStatusBuffer, PMOS_COMMAND_BUFFER pCmdBuffer, uint32_t frameNum);
-
-    virtual MOS_STATUS StopExecutionAtFrame(CodechalHwInterface *hwInterface, PMOS_RESOURCE statusBuffer, PMOS_COMMAND_BUFFER pCmdBuffer, uint32_t numFrame);
-
     MOS_STATUS SetSWCrcMode(bool swCrc);
 
     MOS_STATUS SubmitDummyWorkload(MOS_COMMAND_BUFFER *pcmdBuffer, int32_t bNullRendering);
-    MOS_STATUS DumpYUVSurfaceToBuffer(PMOS_SURFACE surface, uint8_t *buffer, uint32_t &size);
+
     MOS_STATUS LockResource(uint32_t *semaData, PMOS_RESOURCE reSemaphore);
 
     MOS_STATUS DumpToFile(const GoldenReferences &goldenReferences);
 
-    MOS_STATUS StoreNumFrame(PMHW_MI_INTERFACE pMiInterface, PMOS_RESOURCE pResource, int32_t frameNum, PMOS_COMMAND_BUFFER pCmdBuffer);
-
     bool       IsHwDebugHooksEnable() { return m_enableHwDebugHooks; }
 
     void       PackGoldenReferences(std::initializer_list<std::vector<uint32_t>> goldenReferences);
@@ -191,11 +108,9 @@ public:
     MOS_SURFACE       m_temp2DSurfForCopy = {};
     PMOS_INTERFACE    m_osInterface       = nullptr;
     MhwCpInterface   *m_cpInterface       = nullptr;
-    //#ifndef softlet_build
-    MhwMiInterface   *m_miInterface       = nullptr;
-    //#endif
+    void             *m_miInterface       = nullptr;
+
     MediaDbgFunction  m_mediafunction     = MEDIA_FUNCTION_DEFAULT;
-    CODEC_PICTURE     m_currPic;
     uint32_t          m_scaledBottomFieldOffset = 0;
     uint16_t          m_frameType               = 0;
     uint32_t          m_sliceId                 = 0;  // used for constructing debug file name
@@ -211,7 +126,7 @@ public:
     bool              m_swCRC = false;
     uint16_t          m_preIndex                 = 0;
     uint16_t          m_refIndex                 = 0;
-    uint32_t          m_bufferDumpFrameNum       = 0;
+    size_t            m_bufferDumpFrameNum       = 0;
     uint32_t          m_decodeSurfDumpFrameNum   = 0;
     uint32_t          m_streamId                 = 0;
     uint32_t          m_crcTable[256]            ={0};
@@ -219,7 +134,7 @@ public:
     std::vector<uint32_t> m_crcGoldenReference   = {};
     GoldenReferences      m_goldenReferences     = {};
     uint32_t*         m_semaData                 = nullptr;
-
+    MediaUserSettingSharedPtr m_userSettingPtr   = nullptr;
 
 protected:
     MOS_STATUS ReAllocateSurface(
@@ -234,12 +149,6 @@ protected:
         PMOS_RESOURCE presSourceSurface,
         PMOS_RESOURCE presCopiedSurface);
 
-    MOS_STATUS DumpNotSwizzled(
-        std::string  surfName,
-        MOS_SURFACE &surf,
-        uint8_t *    lockedAddr,
-        int32_t      size);
-
     MOS_STATUS DumpBufferInBinary(
         uint8_t *data,
         uint32_t size);
@@ -250,12 +159,15 @@ protected:
         uint32_t height,
         uint32_t pitch);
 
-    virtual MOS_USER_FEATURE_VALUE_ID SetOutputPathKey()  = 0;
-    virtual MOS_USER_FEATURE_VALUE_ID InitDefaultOutput() = 0;
+    virtual MOS_STATUS InitializeUserSetting() { return MOS_STATUS_SUCCESS; };
+
+    virtual std::string SetOutputPathKey()  = 0;
+    virtual std::string InitDefaultOutput() = 0;
 
     std::string          m_outputFileName;
     MediaDebugConfigMgr *m_configMgr = nullptr;
-MEDIA_CLASS_DEFINE_END(MediaDebugInterface)
+
+    MEDIA_CLASS_DEFINE_END(MediaDebugInterface)
 };
 
 #else
