@@ -598,6 +598,7 @@ MOS_STATUS VpAllocator::GetSurfaceInfo(VPHAL_SURFACE *surface, VPHAL_GET_SURFACE
     surface->Format          = resDetails.Format;
     surface->bCompressible   = resDetails.bCompressible ? true : false;
     surface->bIsCompressed   = resDetails.bIsCompressed ? true : false;
+    surface->CacheSetting    = resDetails.CacheSetting;
 
     if (IS_RGB32_FORMAT(surface->Format) ||
         IS_RGB16_FORMAT(surface->Format) ||
@@ -695,6 +696,7 @@ MOS_STATUS VpAllocator::GetSurfaceInfo(VP_SURFACE* surface, VPHAL_GET_SURFACE_IN
     surface->osSurface->Format          = resDetails.Format;
     surface->osSurface->bCompressible   = resDetails.bCompressible ? true : false;
     surface->osSurface->bIsCompressed   = resDetails.bIsCompressed ? true : false;
+    surface->osSurface->CacheSetting    = resDetails.CacheSetting;
     
     return MOS_STATUS_SUCCESS;
 }
@@ -773,7 +775,8 @@ MOS_STATUS VpAllocator::ReAllocateSurface(
         MOS_TILE_MODE_GMM       tileModeByForce,
         Mos_MemPool             memType,
         bool                    isNotLockable,
-        void *                  systemMemory)
+        void *                  systemMemory,
+        uint32_t                depth)
 {
     VP_FUNC_CALL();
     MOS_STATUS              eStatus = MOS_STATUS_SUCCESS;
@@ -838,6 +841,7 @@ MOS_STATUS VpAllocator::ReAllocateSurface(
 
     allocParams.dwWidth         = width;
     allocParams.dwHeight        = height;
+    allocParams.dwDepth         = depth;
     allocParams.Format          = format;
     allocParams.bIsCompressible = compressible;
     allocParams.CompressionMode = compressionMode;
@@ -1320,9 +1324,12 @@ MOS_STATUS VP_SURFACE::Clean()
 uint64_t VP_SURFACE::GetAllocationHandle(MOS_INTERFACE* osIntf)
 {
     VP_FUNC_CALL();
-
+    if (nullptr == osIntf)
+    {
+        return 0;
+    }
 #if MOS_MEDIASOLO_SUPPORTED
-    if (Mos_Solo_IsInUse(osIntf))
+    if (osIntf && osIntf->bSoloInUse)
     {
         uint64_t handle = osSurface ? (uint64_t)osSurface->OsResource.pData : 0;
         if (handle)
@@ -1334,35 +1341,11 @@ uint64_t VP_SURFACE::GetAllocationHandle(MOS_INTERFACE* osIntf)
     }
 #endif
 
-#if(LINUX) && !(WDDM_LINUX)
-    if (osSurface && osSurface->OsResource.bo)
-    {
-        return osSurface->OsResource.bo->handle;
-    }
-    else
+    if (nullptr == osSurface || nullptr == osIntf)
     {
         return 0;
     }
-#elif (_VULKAN)
-    return 0;
-#elif (EMUL)
-    uint64_t handle = osSurface ? (uint64_t)osSurface->OsResource.pData : 0;
-    if (handle)
-    {
-        return handle;
-    }
-    else
-    {
-        return 0;
-    }
-#else
-    if (osSurface == nullptr)
-    {
-        return 0;
-    }
-
-    return MosInterface::GetResourceHandle(osIntf->osStreamState, &osSurface->OsResource);
-#endif
+    return osIntf->pfnGetResourceHandle(osIntf->osStreamState, &osSurface->OsResource);
 }
 
 MOS_STATUS VpAllocator::SetMmcFlags(MOS_SURFACE &osSurface)
