@@ -723,18 +723,30 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                 VP_RENDER_CHK_STATUS_RETURN(UpdateRenderSurface(renderHalSurface, *kernelSurfaceParam));
             }
 
+            if (m_hwInterface->m_vpPlatformInterface->IsRenderMMCLimitationCheckNeeded())
+            {
+                RenderMMCLimitationCheck(vpSurface, renderHalSurface, type);
+            }
+
             uint32_t index = 0;
+            bool     bWrite = renderSurfaceParams.isOutput;
+            if (renderSurfaceParams.bSurfaceTypeDefined)
+            {
+                bWrite = false;
+            }
 
             if (kernelSurfaceParam->surfaceOverwriteParams.bindedKernel && !kernelSurfaceParam->surfaceOverwriteParams.bufferResource)
             {
-                index = SetSurfaceForHwAccess(
+                VP_RENDER_CHK_STATUS_RETURN(SetSurfaceForHwAccess(
                     &renderHalSurface.OsSurface,
                     &renderHalSurface,
                     &renderSurfaceParams,
                     kernelSurfaceParam->surfaceOverwriteParams.bindIndex,
-                    renderSurfaceParams.isOutput,
+                    bWrite,
                     kernelSurfaceParam->surfaceEntries,
-                    kernelSurfaceParam->sizeOfSurfaceEntries);
+                    kernelSurfaceParam->sizeOfSurfaceEntries));
+
+                index = kernelSurfaceParam->surfaceOverwriteParams.bindIndex;
             }
             else
             {
@@ -747,7 +759,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderHalSurface,
                         &renderSurfaceParams,
                         kernelSurfaceParam->surfaceOverwriteParams.bindIndex,
-                        renderSurfaceParams.isOutput);
+                        bWrite);
                 }
                 else if ((kernelSurfaceParam->surfaceOverwriteParams.updatedSurfaceParams &&
                      kernelSurfaceParam->surfaceOverwriteParams.bufferResource            &&
@@ -760,7 +772,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderHalSurface.OsSurface,
                         &renderHalSurface,
                         &renderSurfaceParams,
-                        renderSurfaceParams.isOutput);
+                        bWrite);
                 }
                 else
                 {
@@ -769,7 +781,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderHalSurface.OsSurface,
                         &renderHalSurface,
                         &renderSurfaceParams,
-                        renderSurfaceParams.isOutput);
+                        bWrite);
                 }
             }
             VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCurbeBindingIndex(type, index));
@@ -780,6 +792,103 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
     return MOS_STATUS_SUCCESS;
 }
 
+void VpRenderCmdPacket::RenderMMCLimitationCheck(VP_SURFACE *vpSurface, RENDERHAL_SURFACE_NEXT &renderHalSurface, SurfaceType type)
+{
+    if (vpSurface &&
+        vpSurface->osSurface &&
+        (type == SurfaceTypeFcTarget0 ||
+         type == SurfaceTypeFcTarget1 ||
+         type == SurfaceTypeRenderOutput))
+    {
+        if (!vpSurface->osSurface->OsResource.bUncompressedWriteNeeded &&
+            vpSurface->osSurface->CompressionMode == MOS_MMC_MC        &&
+            IsRenderUncompressedWriteNeeded(vpSurface))
+        {
+            MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+            eStatus = m_renderHal->pOsInterface->pfnDecompResource(m_renderHal->pOsInterface, &vpSurface->osSurface->OsResource);
+
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                VP_RENDER_NORMALMESSAGE("inplace decompression failed for render target.");
+            }
+            else
+            {
+                VP_RENDER_NORMALMESSAGE("inplace decompression enabled for render target RECT is not compression block align.");
+                vpSurface->osSurface->OsResource.bUncompressedWriteNeeded = 1;
+            }
+        }
+        if (vpSurface->osSurface->OsResource.bUncompressedWriteNeeded)
+        {
+            renderHalSurface.OsSurface.CompressionMode = MOS_MMC_MC;
+        }
+    }
+}
+
+bool VpRenderCmdPacket::IsRenderUncompressedWriteNeeded(PVP_SURFACE VpSurface)
+{
+    VP_FUNC_CALL();
+
+    if ((!VpSurface)          ||
+        (!VpSurface->osSurface))
+    {
+        return false;
+    }
+
+    auto *skuTable = m_renderHal->pOsInterface->pfnGetSkuTable(m_renderHal->pOsInterface);
+    if (!MEDIA_IS_SKU(skuTable, FtrE2ECompression))
+    {
+        return false;
+    }
+
+    if (m_renderHal->pOsInterface && m_renderHal->pOsInterface->bSimIsActive)
+    {
+        return false;
+    }
+
+    uint32_t byteInpixel = 1;
+#if !EMUL
+    if (!VpSurface->osSurface->OsResource.pGmmResInfo)
+    {
+        VP_RENDER_NORMALMESSAGE("IsSFCUncompressedWriteNeeded cannot support non GMM info cases");
+        return false;
+    }
+
+    byteInpixel = VpSurface->osSurface->OsResource.pGmmResInfo->GetBitsPerPixel() >> 3;
+#endif // !EMUL
+
+    if (byteInpixel == 0)
+    {
+        VP_RENDER_NORMALMESSAGE("surface format is not a valid format for Render");
+        return false;
+    }
+    uint32_t writeAlignInWidth  = 32 / byteInpixel;
+    uint32_t writeAlignInHeight = 8;
+    
+
+    if ((VpSurface->rcSrc.top % writeAlignInHeight) ||
+        ((VpSurface->rcSrc.bottom - VpSurface->rcSrc.top) % writeAlignInHeight) ||
+        (VpSurface->rcSrc.left % writeAlignInWidth) ||
+        ((VpSurface->rcSrc.right - VpSurface->rcSrc.left) % writeAlignInWidth))
+    {
+        VP_RENDER_NORMALMESSAGE(
+            "Render Target Uncompressed write needed, \
+            VpSurface->rcSrc.top % d, \
+            VpSurface->rcSrc.bottom % d, \
+            VpSurface->rcSrc.left % d, \
+            VpSurface->rcSrc.right % d \
+            VpSurface->Format % d",
+            VpSurface->rcSrc.top,
+            VpSurface->rcSrc.bottom,
+            VpSurface->rcSrc.left,
+            VpSurface->rcSrc.right,
+            VpSurface->osSurface->Format);
+
+        return true;
+    }
+
+    return false;
+}
+
 MOS_STATUS VpRenderCmdPacket::SetupCurbeState()
 {
     VP_FUNC_CALL();
@@ -936,7 +1045,7 @@ MOS_STATUS VpRenderCmdPacket::InitStateHeapSurface(SurfaceType type, RENDERHAL_S
         break;
     default:
         eStatus = MOS_STATUS_UNIMPLEMENTED;
-        VP_RENDER_ASSERTMESSAGE("Not Inplenmented in driver now, return fail");
+        VP_RENDER_ASSERTMESSAGE("Not Inplenmented in driver now, return fail, surfacetype %d", type);
         break;
     }
 
@@ -1506,6 +1615,10 @@ MOS_STATUS VpRenderCmdPacket::SubmitWithMultiKernel(MOS_COMMAND_BUFFER *commandB
 
     RENDER_PACKET_CHK_STATUS_RETURN(SetPowerMode(kernelCombinedFc));
 
+    m_renderHal->pRenderHalPltInterface->On1stLevelBBStart(m_renderHal, commandBuffer, pOsContext, pOsInterface->CurrentGpuContextHandle, pMmioRegisters);
+
+    OcaDumpDbgInfo(*commandBuffer, *pOsContext);
+
     RENDER_PACKET_CHK_STATUS_RETURN(SetMediaFrameTracking(GenericPrologParams));
 
     // Initialize command buffer and insert prolog
@@ -1513,6 +1626,8 @@ MOS_STATUS VpRenderCmdPacket::SubmitWithMultiKernel(MOS_COMMAND_BUFFER *commandB
 
     RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pRenderHalPltInterface->AddPerfCollectStartCmd(m_renderHal, pOsInterface, commandBuffer));
 
+    RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pRenderHalPltInterface->StartPredicate(m_renderHal, commandBuffer));
+
     // Write timing data for 3P budget
     RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pfnSendTimingData(m_renderHal, commandBuffer, true));
 
@@ -1531,6 +1646,8 @@ MOS_STATUS VpRenderCmdPacket::SubmitWithMultiKernel(MOS_COMMAND_BUFFER *commandB
         RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pfnSendRcsStatusTag(m_renderHal, commandBuffer));
     }
 
+    RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pRenderHalPltInterface->StopPredicate(m_renderHal, commandBuffer));
+
     RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pRenderHalPltInterface->AddPerfCollectEndCmd(m_renderHal, pOsInterface, commandBuffer));
 
     // Write timing data for 3P budget
@@ -1580,6 +1697,8 @@ MOS_STATUS VpRenderCmdPacket::SubmitWithMultiKernel(MOS_COMMAND_BUFFER *commandB
         RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pRenderHalPltInterface->AddMediaStateFlush(m_renderHal, commandBuffer, &FlushParam));
     }
 
+    HalOcaInterfaceNext::On1stLevelBBEnd(*commandBuffer, *pOsInterface);
+
     if (pBatchBuffer)
     {
         // Send Batch Buffer end command (HW/OS dependent)
@@ -1595,9 +1714,6 @@ MOS_STATUS VpRenderCmdPacket::SubmitWithMultiKernel(MOS_COMMAND_BUFFER *commandB
         RENDER_PACKET_CHK_STATUS_RETURN(m_renderHal->pRenderHalPltInterface->AddMiBatchBufferEnd(m_renderHal, commandBuffer, nullptr));
     }
 
-    // Return unused command buffer space to OS
-    pOsInterface->pfnReturnCommandBuffer(pOsInterface, commandBuffer, 0);
-
     MOS_NULL_RENDERING_FLAGS NullRenderingFlags;
 
     NullRenderingFlags =
@@ -1928,6 +2044,7 @@ MOS_STATUS VpRenderCmdPacket::SetHdrParams(PRENDER_HDR_PARAMS params)
 
     params->coeffAllocated       = m_surfSetting.coeffAllocated;
     params->OETF1DLUTAllocated   = m_surfSetting.OETF1DLUTAllocated;
+    params->Cri3DLUTAllocated    = m_surfSetting.Cri3DLUTAllocated;
     params->pHDRStageConfigTable = m_surfSetting.pHDRStageConfigTable;
 
     //MOS_SURFACE *surface = surf->osSurface;
