@@ -67,7 +67,7 @@ typedef struct _KERNEL_SURFACE_STATE_PARAM
         RENDERHAL_SURFACE_STATE_PARAMS renderSurfaceParams;  // default can be skip. for future usages, if surface configed by kernel, use it directlly
     } surfaceOverwriteParams;
 
-    bool                                renderTarget;        // true for render target
+    bool                                isOutput;        // true for render target
     PRENDERHAL_SURFACE_STATE_ENTRY      *surfaceEntries;
     uint32_t                            *sizeOfSurfaceEntries;
 } KERNEL_SURFACE_STATE_PARAM;
@@ -350,6 +350,11 @@ public:
         return m_kernelId;
     }
 
+    DelayLoadedKernelType GetKernelType()
+    {
+        return m_kernelType;
+    }
+
     virtual bool IsKernelCached()
     {
         return false;
@@ -480,6 +485,11 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    virtual MOS_STATUS SetPerfTag()
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
     virtual MOS_STATUS InitRenderHalSurface(
         SurfaceType             type,
         VP_SURFACE              *surf,
@@ -500,12 +510,9 @@ protected:
 
     virtual MOS_STATUS SetKernelConfigs(KERNEL_CONFIGS& kernelConfigs);
 
-    MOS_STATUS SetProcessSurfaceGroup(VP_SURFACE_GROUP& surfaces)
-    {
-        m_surfaceGroup = &surfaces;
-        VP_RENDER_CHK_STATUS_RETURN(SetupSurfaceState());
-        return MOS_STATUS_SUCCESS;
-    }
+    virtual MOS_STATUS SetProcessSurfaceGroup(VP_SURFACE_GROUP &surfaces);
+
+    virtual MOS_STATUS CpPrepareResources();
 
     virtual MOS_STATUS GetCurbeState(void *&curbe, uint32_t &curbeLength) = 0;
 
@@ -530,13 +537,14 @@ protected:
     uint32_t                                                m_kernelBinaryID = 0;
     uint32_t                                                m_kernelSize = 0;
     VpKernelID                                              m_kernelId = kernelCombinedFc;
+    DelayLoadedKernelType                                   m_kernelType     = KernelNone;
     KernelIndex                                             m_kernelIndex = 0;          // index of current kernel in KERNEL_PARAMS_LIST
 
     bool                                                    m_isAdvKernel = false;      // true mean multi kernel can be submitted in one workload.
 
     std::shared_ptr<mhw::vebox::Itf>                        m_veboxItf = nullptr;
 
-MEDIA_CLASS_DEFINE_END(VpRenderKernelObj)
+MEDIA_CLASS_DEFINE_END(vp__VpRenderKernelObj)
 };
 }
 #endif // __VP_RENDER_KERNEL_OBJ_H__
