@@ -1387,7 +1387,7 @@ MOS_STATUS SfcRenderBase::AllocateLineBuffer(VP_SURFACE *&lineBuffer, uint32_t s
 
     VP_PUBLIC_CHK_NULL_RETURN(m_osInterface)
 
-    skuTable = MosInterface::GetSkuTable(m_osInterface->osStreamState);
+    skuTable = m_osInterface->pfnGetSkuTable(m_osInterface);
 
     if (skuTable && MEDIA_IS_SKU(skuTable, FtrLimitedLMemBar))
     {
@@ -1472,7 +1472,7 @@ MOS_STATUS SfcRenderBase::AllocateResources()
     size = GetIefLineBufferSize(false, m_renderData.sfcStateParams->dwScaledRegionHeight);
     VP_RENDER_CHK_STATUS_RETURN(AllocateLineBufferArray(m_IEFLineBufferSurfaceArray, size, "SfcIEFLineBufferSurface"));
 
-    if (m_renderData.sfcStateParams->dwScaledRegionHeight > SFC_LINEBUFEER_SIZE_LIMITED)
+    if (m_bVdboxToSfc || m_renderData.sfcStateParams->dwScaledRegionHeight > SFC_LINEBUFEER_SIZE_LIMITED)
     {
         // Allocate SFD Line Buffer surface
         size = GetSfdLineBufferSize(false, m_renderData.sfcStateParams->OutputFrameFormat, m_renderData.sfcStateParams->dwScaledRegionWidth, m_renderData.sfcStateParams->dwScaledRegionHeight);
