@@ -30,7 +30,7 @@
 #include "mos_utilities.h"
 #include "vp_common.h"
 #include "renderhal.h"
-#include "vphal.h"
+#include "vp_base.h"
 
 namespace vp
 {
@@ -62,10 +62,19 @@ using PCVP_PIPELINE_PARAMS = const VPHAL_RENDER_PARAMS*;
 #define RESOURCE_ASSIGNMENT_HINT_BITS_HDR       \
     uint32_t    is3DLut2DNeeded     : 1;
 
+#define RESOURCE_ASSIGNMENT_HINT_BITS_DENOISE \
+    uint32_t isHVSTableNeeded : 1;
+
+#define RESOURCE_ASSIGNMENT_HINT_BITS_STD_ALONE \
+    uint32_t isSkinScoreDumpNeededForSTDonly : 1; \
+    uint32_t isSkinScoreOutputNeededForSTDOnly : 1;
+
 #define RESOURCE_ASSIGNMENT_HINT_BITS           \
         RESOURCE_ASSIGNMENT_HINT_BITS_DI        \
         RESOURCE_ASSIGNMENT_HINT_BITS_SCALING   \
-        RESOURCE_ASSIGNMENT_HINT_BITS_HDR
+        RESOURCE_ASSIGNMENT_HINT_BITS_HDR       \
+        RESOURCE_ASSIGNMENT_HINT_BITS_DENOISE   \
+        RESOURCE_ASSIGNMENT_HINT_BITS_STD_ALONE
 
 #define RESOURCE_ASSIGNMENT_HINT_SIZE   4
 
@@ -121,6 +130,7 @@ struct _VP_SETTINGS
     uint32_t               kernelUpdate           = 0;                   //!< For VEBox Copy and Update kernels
     uint32_t               disableHdr             = 0;                   //!< Disable Hdr
     uint32_t               veboxParallelExecution = 0;                   //!< Control VEBox parallel execution with render engine
+    bool                   clearVideoViewMode     = 0;                   //!< Perf Optimize for ClearVideoView DDI
 };
 
 using VP_SETTINGS = _VP_SETTINGS;
@@ -134,11 +144,13 @@ struct _VP_EXECUTE_CAPS
             uint64_t bSFC           : 1;   // SFC needed
             uint64_t bRender        : 1;   // Render Only needed
             uint64_t bSecureVebox   : 1;   // Vebox in Secure Mode
+            uint64_t bRenderHdr     : 1;   // Render HDR in use
 
             uint64_t bOutputPipeFeatureInuse : 1; // Output surface of pipeline is in use.
             uint64_t bForceCscToRender : 1; // If true, force to use render for csc.
             uint64_t bForceProcampToRender : 1;   // If true, force to use render for procamp.
             uint64_t lastSubmission : 1;    // If true, it's the last submission of current DDI.
+            uint64_t bTemperalInputInuse : 1; // If true, will use temperal input instead of input
 
             // Vebox Features
             uint64_t bDN            : 1;   // Vebox DN needed
@@ -146,7 +158,7 @@ struct _VP_EXECUTE_CAPS
             uint64_t bDiProcess2ndField : 1;   // Vebox DI enabled
             uint64_t bDIFmdKernel   : 1;   // Vebox FMD Kernel enabled
             uint64_t bIECP          : 1;   // Vebox IECP needed
-            uint64_t bSTE           : 1;   // Vebox STE needed
+            uint64_t bSTE           : 1;   // Vebox STE or Vebox STD_alone needed
             uint64_t bACE           : 1;   // Vebox ACE needed
             uint64_t bTCC           : 1;   // Vebox TCC needed
             uint64_t bCGC           : 1;   // Vebox CGC needed
@@ -164,6 +176,8 @@ struct _VP_EXECUTE_CAPS
             uint64_t b3DlutOutput   : 1;
             uint64_t bCappipe       : 1;
             uint64_t bLgca          : 1;
+            uint64_t bFDFB          : 1;
+            uint64_t bColorBalance  : 1;
 
             // SFC features
             uint64_t bSfcCsc        : 1;   // Sfc Csc enabled
@@ -176,6 +190,9 @@ struct _VP_EXECUTE_CAPS
             uint64_t bComposite     : 1;
             uint64_t bSR            : 1;
             uint64_t b3DLutCalc     : 1;
+            uint64_t bHVSCalc       : 1;
+            uint64_t bSegmentation  : 1;
+            uint64_t bHdr           : 1;
         };
         uint64_t value;
     };
@@ -189,16 +206,23 @@ typedef struct _VP_EngineEntry
     {
         struct
         {
+            // set by GetXxxExecuteCaps
             uint32_t bEnabled : 1;
             uint32_t SfcNeeded : 1;
             uint32_t VeboxNeeded : 1;
             uint32_t RenderNeeded : 1;
+            uint32_t hdrKernelNeeded : 1;
             uint32_t fcSupported : 1;           // Supported by fast composition
+            uint32_t hdrKernelSupported : 1;    // Supported by Hdr Kenrel
             uint32_t isolated : 1;              // Only support single feature.
+            uint32_t bt2020ToRGB : 1;           // true if bt2020 to rgb
+
+            // set by GetXxxPipeEnginCaps
             uint32_t bypassIfVeboxSfcInUse : 1; // Bypass the feature if vebox or sfc in use. In such case, VeboxNeeded and
                                                 // SfcNeeded are 0 but it should not block vebox or sfc being selected. 
             uint32_t forceEnableForSfc : 1;     // Force enabled when sfc being selected.
-            uint32_t forceEnableForRender : 1;  // Force enabled when render being selected.
+            uint32_t forceEnableForFc  : 1;     // Force enabled when fc being selected.
+            uint32_t forceEnableForHdrKernel : 1;
             uint32_t nonFcFeatureExists : 1;    // The feature exists, which do not support fc
             uint32_t nonVeboxFeatureExists : 1; // The feature exists, which do not support vebox
             uint32_t fcOnlyFeatureExists : 1;   // The feature exists, which only support render fc, and not support vebox/sfc.
@@ -213,7 +237,10 @@ typedef struct _VP_EngineEntry
             uint32_t usedForNextPass : 1;       // true if current feature should be bypassed for current pass and be processed during next pass.
             uint32_t sfcNotSupported : 1;       // true if sfc cannot be selected.
             uint32_t veboxNotSupported : 1;     // true if vebox cannot be selected.
-            uint32_t onlyParamCalculation : 1;  // true if the feature is used for parameter calculation.
+            uint32_t isOutputPipeNeeded : 1;    // true if the feature is used for parameter calculation.
+            uint32_t sfcOnlyFeatureExists : 1;  // The feature exists, which only support sfc.
+            uint32_t bTemperalInputInuse : 1;   // true if replace input
+            uint32_t veboxRGBOutputWithoutLumaKey : 1;
         };
         uint32_t value;
     };
