@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2022, Intel Corporation
+* Copyright (c) 2022-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -965,46 +965,4 @@ void DdiDecodeJpeg::FreeResource()
     return;
 }
 
-VAStatus DdiDecodeJpeg::CheckDecodeResolution(
-    int32_t   codecMode,
-    VAProfile profile,
-    uint32_t  width,
-    uint32_t  height)
-{
-    uint32_t maxWidth = 0, maxHeight = 0;
-    switch (codecMode)
-    {
-    case CODECHAL_DECODE_MODE_JPEG:
-        maxWidth  = m_decJpegMaxWidth;
-        maxHeight = m_decJpegMaxHeight;
-        break;
-    default:
-        maxWidth  = m_decDefaultMaxWidth;
-        maxHeight = m_decDefaultMaxHeight;
-        break;
-    }
-
-    if (width > maxWidth || height > maxHeight)
-    {
-        return VA_STATUS_ERROR_RESOLUTION_NOT_SUPPORTED;
-    }
-    else
-    {
-        return VA_STATUS_SUCCESS;
-    }
-}
-
-CODECHAL_MODE DdiDecodeJpeg::GetDecodeCodecMode(VAProfile profile)
-{
-    int8_t vaProfile = (int8_t)profile;
-    switch (vaProfile)
-    {
-    case VAProfileJPEGBaseline:
-        return CODECHAL_DECODE_MODE_JPEG;
-    default:
-        DDI_CODEC_ASSERTMESSAGE("Invalid Decode Mode");
-        return CODECHAL_UNSUPPORTED_MODE;
-    }
-}
-
 } // namespace decode
